

class Ethernet(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Ethernet

    Emulated ethernet protocol  
    A top level in the emulated device stack  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - mac (Pattern): A container for emulated device property patterns
     Media access control address (MAC) is a 48bit identifier for use as a network address
     The value can be an int or a hex string with or without spaces or colons separating each byte
     The min value is 0 or '00:00:00:00:00:00'
     The max value is 281474976710655 or 'FF:FF:FF:FF:FF:FF'
    - mtu (Pattern): A container for emulated device property patterns
    - vlans (list[Vlan]): List of vlans
    """
    def __init__(self, name=None, mac=None, mtu=None, vlans=[]):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(mac, (Pattern, type(None))) is True:
            self.mac = mac
        else:
            raise TypeError('mac must be an instance of (Pattern, type(None))')
        if isinstance(mtu, (Pattern, type(None))) is True:
            self.mtu = mtu
        else:
            raise TypeError('mtu must be an instance of (Pattern, type(None))')
        if isinstance(vlans, (list, type(None))) is True:
            self.vlans = [] if vlans is None else list(vlans)
        else:
            raise TypeError('vlans must be an instance of (list, type(None))')


class Pattern(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Pattern

    A container for emulated device property patterns  

    Args
    ----
    - choice (Union[str, list, Counter, Random]): TBD
    """
    _CHOICE_MAP = {
        'str': 'fixed',
        'list': 'list',
        'Counter': 'counter',
        'Random': 'random',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.device import Counter
        from abstract_open_traffic_generator.device import Random
        if isinstance(choice, (str, list, Counter, Random)) is False:
            raise TypeError('choice must be of type: str, list, Counter, Random')
        self.__setattr__('choice', Pattern._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Pattern._CHOICE_MAP[type(choice).__name__], choice)


class Counter(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Counter

    An incrementing pattern  

    Args
    ----
    - start (str): TBD
    - step (str): TBD
    - up (Union[True, False]): TBD
    """
    def __init__(self, start=None, step=None, up=True):
        if isinstance(start, (str, type(None))) is True:
            self.start = start
        else:
            raise TypeError('start must be an instance of (str, type(None))')
        if isinstance(step, (str, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (str, type(None))')
        if isinstance(up, (bool, type(None))) is True:
            self.up = up
        else:
            raise TypeError('up must be an instance of (bool, type(None))')


class Random(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Random

    A repeatable random range pattern  

    Args
    ----
    - min (str): TBD
    - max (str): TBD
    - step (Union[float, int]): TBD
    - seed (str): TBD
    """
    def __init__(self, min=None, max=None, step=None, seed=None):
        if isinstance(min, (str, type(None))) is True:
            self.min = min
        else:
            raise TypeError('min must be an instance of (str, type(None))')
        if isinstance(max, (str, type(None))) is True:
            self.max = max
        else:
            raise TypeError('max must be an instance of (str, type(None))')
        if isinstance(step, (float, int, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (float, int, type(None))')
        if isinstance(seed, (str, type(None))) is True:
            self.seed = seed
        else:
            raise TypeError('seed must be an instance of (str, type(None))')


class Vlan(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Vlan

    Emulated vlan protocol  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - tpid (Pattern): A container for emulated device property patterns
     Vlan tag protocol identifier
    - priority (Pattern): A container for emulated device property patterns
     Vlan priority
    - id (Pattern): A container for emulated device property patterns
     Vlan id
    """
    
    TPID_8100 = '8100'
    TPID_88A8 = '88a8'
    TPID_9100 = '9100'
    TPID_9200 = '9200'
    TPID_9300 = '9300'
    
    def __init__(self, name=None, tpid=None, priority=None, id=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(tpid, (Pattern, type(None))) is True:
            self.tpid = tpid
        else:
            raise TypeError('tpid must be an instance of (Pattern, type(None))')
        if isinstance(priority, (Pattern, type(None))) is True:
            self.priority = priority
        else:
            raise TypeError('priority must be an instance of (Pattern, type(None))')
        if isinstance(id, (Pattern, type(None))) is True:
            self.id = id
        else:
            raise TypeError('id must be an instance of (Pattern, type(None))')


class Device(object):
    """Generated from OpenAPI schema object #/components/schemas/Device

    A container for emulated protocol devices  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - container_name (str): The unique name of a Port or Lag object that will contain the emulated interfaces and/or devices
    - device_count (int): The number of emulated protocol devices or interfaces per port
     Example: If the device_count is 10 and the choice property value is ethernet then an implementation MUST create 10 ethernet interfaces
     The ethernet property is a container for src, dst and eth_type properties with each on of those properties being a pattern container for 10 possible values
     If an implementation is unable to support the maximum device_count it MUST indicate what the maximum device_count is using the /results/capabilities API
     The device_count is also used by the individual child properties that are a container for a /components/schemas/Device
     Pattern
    - choice (Union[Ethernet, Ipv4, Ipv6, Bgpv4]): The type of emulated protocol interface or device
    """
    _CHOICE_MAP = {
        'Ethernet': 'ethernet',
        'Ipv4': 'ipv4',
        'Ipv6': 'ipv6',
        'Bgpv4': 'bgpv4',
    }
    def __init__(self, name=None, container_name=None, device_count=1, choice=None):
        from abstract_open_traffic_generator.device import Ethernet
        from abstract_open_traffic_generator.device import Ipv4
        from abstract_open_traffic_generator.device import Ipv6
        from abstract_open_traffic_generator.device import Bgpv4
        if isinstance(choice, (Ethernet, Ipv4, Ipv6, Bgpv4)) is False:
            raise TypeError('choice must be of type: Ethernet, Ipv4, Ipv6, Bgpv4')
        self.__setattr__('choice', Device._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Device._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(container_name, (str)) is True:
            self.container_name = container_name
        else:
            raise TypeError('container_name must be an instance of (str)')
        if isinstance(device_count, (float, int, type(None))) is True:
            self.device_count = device_count
        else:
            raise TypeError('device_count must be an instance of (float, int, type(None))')


class Ipv4(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Ipv4

    Emulated ipv4 protocol  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - address (Pattern): A container for emulated device property patterns
     The ipv4 address
    - gateway (Pattern): A container for emulated device property patterns
     The ipv4 address of the gateway
    - prefix (Pattern): A container for emulated device property patterns
     The prefix of the ipv4 address
    - ethernet (Ethernet): Emulated ethernet protocol
     A top level in the emulated device stack
    """
    def __init__(self, name=None, address=None, gateway=None, prefix=None, ethernet=None):
        from abstract_open_traffic_generator.device import Pattern
        from abstract_open_traffic_generator.device import Ethernet
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(gateway, (Pattern, type(None))) is True:
            self.gateway = gateway
        else:
            raise TypeError('gateway must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(ethernet, (Ethernet, type(None))) is True:
            self.ethernet = ethernet
        else:
            raise TypeError('ethernet must be an instance of (Ethernet, type(None))')


class Ipv6(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Ipv6

    Emulated ipv6 protocol  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - address (Pattern): A container for emulated device property patterns
    - gateway (Pattern): A container for emulated device property patterns
    - prefix (Pattern): A container for emulated device property patterns
    - ethernet (Ethernet): Emulated ethernet protocol
     A top level in the emulated device stack
    """
    def __init__(self, name=None, address=None, gateway=None, prefix=None, ethernet=None):
        from abstract_open_traffic_generator.device import Pattern
        from abstract_open_traffic_generator.device import Ethernet
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(gateway, (Pattern, type(None))) is True:
            self.gateway = gateway
        else:
            raise TypeError('gateway must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(ethernet, (Ethernet, type(None))) is True:
            self.ethernet = ethernet
        else:
            raise TypeError('ethernet must be an instance of (Ethernet, type(None))')


class Bgpv4(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Bgpv4

    Emulated BGPv4 router and routes  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - router_id (Pattern): A container for emulated device property patterns
     specifies BGP router identifier
     It must be the string representation of an IPv4 address
    - as_number (Pattern): A container for emulated device property patterns
     Autonomous system (AS) number of 4 byte
    - as_type (Union[ibgp, ebgp]): The type of BGP autonomous system
     External BGP (EBGP) is used for BGP links between two or more autonomous systems
     Internal BGP (IBGP) is used within a single autonomous system
    - hold_time_interval (Pattern): A container for emulated device property patterns
     Number of seconds the sender proposes for the value of the Hold Timer
    - keep_alive_interval (Pattern): A container for emulated device property patterns
     Number of seconds between transmissions of Keep Alive messages by router
    - dut_ipv4_address (Pattern): A container for emulated device property patterns
     IPv4 address of the BGP peer for the session
    - dut_as_number (Pattern): A container for emulated device property patterns
     Autonomous system (AS) number of the BGP peer router (DUT)
    - ipv4 (Ipv4): Emulated ipv4 protocolThe ipv4 stack that the bgp4 protocol is implemented over
    - bgpv4_route_range (list[Bgpv4RouteRange]): Emulated BGPv4 route range
    - bgpv6_route_range (list[Bgpv6RouteRange]): Emulated bgpv6 route range
    """
    def __init__(self, name=None, router_id=None, as_number=None, as_type=None, hold_time_interval=None, keep_alive_interval=None, dut_ipv4_address=None, dut_as_number=None, ipv4=None, bgpv4_route_range=[], bgpv6_route_range=[]):
        from abstract_open_traffic_generator.device import Pattern
        from abstract_open_traffic_generator.device import Ipv4
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(router_id, (Pattern, type(None))) is True:
            self.router_id = router_id
        else:
            raise TypeError('router_id must be an instance of (Pattern, type(None))')
        if isinstance(as_number, (Pattern, type(None))) is True:
            self.as_number = as_number
        else:
            raise TypeError('as_number must be an instance of (Pattern, type(None))')
        if isinstance(as_type, (str, type(None))) is True:
            self.as_type = as_type
        else:
            raise TypeError('as_type must be an instance of (str, type(None))')
        if isinstance(hold_time_interval, (Pattern, type(None))) is True:
            self.hold_time_interval = hold_time_interval
        else:
            raise TypeError('hold_time_interval must be an instance of (Pattern, type(None))')
        if isinstance(keep_alive_interval, (Pattern, type(None))) is True:
            self.keep_alive_interval = keep_alive_interval
        else:
            raise TypeError('keep_alive_interval must be an instance of (Pattern, type(None))')
        if isinstance(dut_ipv4_address, (Pattern, type(None))) is True:
            self.dut_ipv4_address = dut_ipv4_address
        else:
            raise TypeError('dut_ipv4_address must be an instance of (Pattern, type(None))')
        if isinstance(dut_as_number, (Pattern, type(None))) is True:
            self.dut_as_number = dut_as_number
        else:
            raise TypeError('dut_as_number must be an instance of (Pattern, type(None))')
        if isinstance(ipv4, (Ipv4, type(None))) is True:
            self.ipv4 = ipv4
        else:
            raise TypeError('ipv4 must be an instance of (Ipv4, type(None))')
        if isinstance(bgpv4_route_range, (list, type(None))) is True:
            self.bgpv4_route_range = [] if bgpv4_route_range is None else list(bgpv4_route_range)
        else:
            raise TypeError('bgpv4_route_range must be an instance of (list, type(None))')
        if isinstance(bgpv6_route_range, (list, type(None))) is True:
            self.bgpv6_route_range = [] if bgpv6_route_range is None else list(bgpv6_route_range)
        else:
            raise TypeError('bgpv6_route_range must be an instance of (list, type(None))')


class Bgpv4RouteRange(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Bgpv4RouteRange

    Emulated BGPv4 route range  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - route_count_per_device (int): The number of routes per device
    - address (Pattern): A container for emulated device property patterns
     The network address of the first network
    - prefix (Pattern): A container for emulated device property patterns
     Ipv4 prefix length with minimum value is 0 to maximum value is 32
    - as_path (Pattern): A container for emulated device property patterns
     Autonomous Systems (AS) numbers that a route passes through to reach the destination
    - next_hop_address (Pattern): A container for emulated device property patterns
     IP Address of next router to forward a packet to its final destination
    - community (Pattern): A container for emulated device property patterns
     BGP communities provide additional capability for tagging routes and for modifying BGP routing policy on upstream and downstream routers BGP community is a 32-bit number which broken into 16-bit As and 16-bit custom value Please specify those two values in this string format 65000:100
    """
    def __init__(self, name=None, route_count_per_device=1, address=None, prefix=None, as_path=None, next_hop_address=None, community=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(route_count_per_device, (float, int, type(None))) is True:
            self.route_count_per_device = route_count_per_device
        else:
            raise TypeError('route_count_per_device must be an instance of (float, int, type(None))')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(as_path, (Pattern, type(None))) is True:
            self.as_path = as_path
        else:
            raise TypeError('as_path must be an instance of (Pattern, type(None))')
        if isinstance(next_hop_address, (Pattern, type(None))) is True:
            self.next_hop_address = next_hop_address
        else:
            raise TypeError('next_hop_address must be an instance of (Pattern, type(None))')
        if isinstance(community, (Pattern, type(None))) is True:
            self.community = community
        else:
            raise TypeError('community must be an instance of (Pattern, type(None))')


class Bgpv6RouteRange(object):
    """Generated from OpenAPI schema object #/components/schemas/Device.Bgpv6RouteRange

    Emulated bgpv6 route range  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - route_count_per_device (int): The number of routes per device
    - address (Pattern): A container for emulated device property patterns
     The network address of the first network
    - prefix (Pattern): A container for emulated device property patterns
     Ipv6 prefix length with minimum value is 0 to maximum value is 128
    - as_path (Pattern): A container for emulated device property patterns
     Autonomous Systems (AS) numbers that a route passes through to reach the destination
    - next_hop_address (Pattern): A container for emulated device property patterns
     IP Address of next router to forward a packet to its final destination
    - community (Pattern): A container for emulated device property patterns
     BGP communities provide additional capability for tagging routes and for modifying BGP routing policy on upstream and downstream routers BGP community is a 32-bit number which broken into 16-bit As and 16-bit custom value Please specify those two values in this string format 65000:100
    """
    def __init__(self, name=None, route_count_per_device=1, address=None, prefix=None, as_path=None, next_hop_address=None, community=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(route_count_per_device, (float, int, type(None))) is True:
            self.route_count_per_device = route_count_per_device
        else:
            raise TypeError('route_count_per_device must be an instance of (float, int, type(None))')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(as_path, (Pattern, type(None))) is True:
            self.as_path = as_path
        else:
            raise TypeError('as_path must be an instance of (Pattern, type(None))')
        if isinstance(next_hop_address, (Pattern, type(None))) is True:
            self.next_hop_address = next_hop_address
        else:
            raise TypeError('next_hop_address must be an instance of (Pattern, type(None))')
        if isinstance(community, (Pattern, type(None))) is True:
            self.community = community
        else:
            raise TypeError('community must be an instance of (Pattern, type(None))')



import pytest
from abstract_open_traffic_generator.config import Config
from abstract_open_traffic_generator.flow import *
from abstract_open_traffic_generator.flow_ipv4 import Priority, Dscp


def test_port_traffic(serializer, tx, rx):
    dscp = Dscp(phb=Pattern(Dscp.PHB_EF46), 
        ecn=Pattern(Dscp.ECN_CAPABLE_TRANSPORT_1))
    ipv4 = Ipv4(src=Pattern('1.1.1.1'), 
        dst=Pattern(Counter(start='1.1.2.1', step='0.0.0.1', count=10)), 
        priority=Priority(dscp))
    background = Flow(name='Background Traffic', 
        tx_rx=TxRx(PortTxRx(tx_port_name=tx.name)),
        packet=[Header(Ethernet()), Header(Vlan()), Header(ipv4)],
        size=Size(512),
        rate=Rate(unit='pps', value=1000000),
        duration=Duration(Continuous()))
    config = Config(ports=[tx], flows=[background])
    print(serializer.json(config))


def test_port_pfc_pause_traffic(serializer, tx, rx):
    pfc_pause = PfcPause(dst=Pattern('000001020304'),
        src=Pattern('0000002030405'),
        control_op_code=Pattern('01'))
    pfc_flow = Flow(name='Pfc Traffic', 
        tx_rx=TxRx(PortTxRx(tx_port_name=tx.name)),
        packet=[Header(pfc_pause)],
        size=Size(64),
        rate=Rate(unit='pps', value=1000000),
        duration=Duration(Continuous()))
    config = Config(ports=[tx], flows=[pfc_flow])
    print(serializer.json(config))


if __name__ == '__main__':
    pytest.main(['-s', __file__])



import pytest
from abstract_open_traffic_generator.config import Config
from abstract_open_traffic_generator.port import Port
from abstract_open_traffic_generator.device import *


def test_devices(serializer):
    """Demonstrate how to build a device configuration on a port
    """
    config = Config()
    config.ports.append(Port(name='port1'))
    bgpv4 = Bgpv4(name='bgpv4',
                  ipv4=Ipv4(name='ipv4',
                            ethernet=Ethernet(name='eth1',
                                              vlans=[
                                                  Vlan(name='vlan1'),
                                                  Vlan(name='vlan2'),
                                                  Vlan(name='vlan3')
                                              ])))
    device = Device(name='device',
                    container_name=config.ports[0].name,
                    choice=bgpv4,
                    device_count=10)
    config.devices.append(device)
    print(serializer.json(config))


if __name__ == '__main__':
    pytest.main(['-s', __file__])





class Flow(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow

    A high level data plane traffic flow  
    Acts as a container for endpoints, frame size, frame rate, duration and packet headers  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - tx_rx (TxRx): A container for different types of transmit and receive endpoint containers
    - packet (list[Header]): The packet is a list of traffic protocol headers
     The order of traffic protocol headers assigned to the list is the order they will appear on the wire
    - size (Size): The frame size which overrides the total length of the packet
    - rate (Rate): The rate of packet transmission
    - duration (Duration): A container for different transmit durations
    """
    def __init__(self, name=None, tx_rx=None, packet=[], size=None, rate=None, duration=None):
        from abstract_open_traffic_generator.flow import TxRx
        from abstract_open_traffic_generator.flow import Size
        from abstract_open_traffic_generator.flow import Rate
        from abstract_open_traffic_generator.flow import Duration
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(tx_rx, (TxRx)) is True:
            self.tx_rx = tx_rx
        else:
            raise TypeError('tx_rx must be an instance of (TxRx)')
        if isinstance(packet, (list, type(None))) is True:
            self.packet = [] if packet is None else list(packet)
        else:
            raise TypeError('packet must be an instance of (list, type(None))')
        if isinstance(size, (Size, type(None))) is True:
            self.size = size
        else:
            raise TypeError('size must be an instance of (Size, type(None))')
        if isinstance(rate, (Rate, type(None))) is True:
            self.rate = rate
        else:
            raise TypeError('rate must be an instance of (Rate, type(None))')
        if isinstance(duration, (Duration, type(None))) is True:
            self.duration = duration
        else:
            raise TypeError('duration must be an instance of (Duration, type(None))')


class TxRx(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.TxRx

    A container for different types of transmit and receive endpoint containers  

    Args
    ----
    - choice (Union[PortTxRx, DeviceTxRx]): The type of transmit and receive container used by the flow
    """
    _CHOICE_MAP = {
        'PortTxRx': 'port',
        'DeviceTxRx': 'device',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import PortTxRx
        from abstract_open_traffic_generator.flow import DeviceTxRx
        if isinstance(choice, (PortTxRx, DeviceTxRx)) is False:
            raise TypeError('choice must be of type: PortTxRx, DeviceTxRx')
        self.__setattr__('choice', TxRx._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(TxRx._CHOICE_MAP[type(choice).__name__], choice)


class PortTxRx(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.PortTxRx

    A container for a transmit port and 0..n intended receive ports  
    When assigning this container to a flow the flows's packet headers will not be populated with any address resolution information such as source and/or destination addresses  
    For example Flow.Ethernet dst mac address values will be defaulted to 0  
    For full control over the Flow.properties.packet header contents use this container  

    Args
    ----
    - tx_port_name (str): The unique name of a port that is the transmit port
    - rx_port_name (str): The unique name of a port that is the intended receive port
    """
    def __init__(self, tx_port_name=None, rx_port_name=None):
        if isinstance(tx_port_name, (str)) is True:
            self.tx_port_name = tx_port_name
        else:
            raise TypeError('tx_port_name must be an instance of (str)')
        if isinstance(rx_port_name, (str, type(None))) is True:
            self.rx_port_name = rx_port_name
        else:
            raise TypeError('rx_port_name must be an instance of (str, type(None))')


class DeviceTxRx(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.DeviceTxRx

    A container for 1..n transmit devices and 1..n receive devices  
    Implemementations may use learned information from the devices to pre-populate Flow.properties.packet[Flow.Header fields]  
    For example an implementation may automatically start devices, get arp table information and pre-populate the Flow.Ethernet dst mac address values  
    To discover what the implementation supports use the /results/capabilities API  

    Args
    ----
    - tx_device_names (list[str]): The unique names of devices that will be transmitting
    - rx_device_names (list[str]): The unique names of emulated devices that will be receiving
    """
    def __init__(self, tx_device_names=[], rx_device_names=[]):
        if isinstance(tx_device_names, (list)) is True:
            self.tx_device_names = tx_device_names
        else:
            raise TypeError('tx_device_names must be an instance of (list)')
        if isinstance(rx_device_names, (list)) is True:
            self.rx_device_names = rx_device_names
        else:
            raise TypeError('rx_device_names must be an instance of (list)')


class Header(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Header

    Container for all traffic packet headers  

    Args
    ----
    - choice (Union[Custom, Ethernet, Vlan, Vxlan, Ipv4, Ipv6, PfcPause, EthernetPause, Tcp, Udp, Gre, Gtpv1, Gtpv2]): TBD
    """
    _CHOICE_MAP = {
        'Custom': 'custom',
        'Ethernet': 'ethernet',
        'Vlan': 'vlan',
        'Vxlan': 'vxlan',
        'Ipv4': 'ipv4',
        'Ipv6': 'ipv6',
        'PfcPause': 'pfcpause',
        'EthernetPause': 'ethernetpause',
        'Tcp': 'tcp',
        'Udp': 'udp',
        'Gre': 'gre',
        'Gtpv1': 'gtpv1',
        'Gtpv2': 'gtpv2',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import Custom
        from abstract_open_traffic_generator.flow import Ethernet
        from abstract_open_traffic_generator.flow import Vlan
        from abstract_open_traffic_generator.flow import Vxlan
        from abstract_open_traffic_generator.flow import Ipv4
        from abstract_open_traffic_generator.flow import Ipv6
        from abstract_open_traffic_generator.flow import PfcPause
        from abstract_open_traffic_generator.flow import EthernetPause
        from abstract_open_traffic_generator.flow import Tcp
        from abstract_open_traffic_generator.flow import Udp
        from abstract_open_traffic_generator.flow import Gre
        from abstract_open_traffic_generator.flow import Gtpv1
        from abstract_open_traffic_generator.flow import Gtpv2
        if isinstance(choice, (Custom, Ethernet, Vlan, Vxlan, Ipv4, Ipv6, PfcPause, EthernetPause, Tcp, Udp, Gre, Gtpv1, Gtpv2)) is False:
            raise TypeError('choice must be of type: Custom, Ethernet, Vlan, Vxlan, Ipv4, Ipv6, PfcPause, EthernetPause, Tcp, Udp, Gre, Gtpv1, Gtpv2')
        self.__setattr__('choice', Header._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Header._CHOICE_MAP[type(choice).__name__], choice)


class Custom(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Custom

    Custom packet header  

    Args
    ----
    - bytes (str): A custom packet header defined as a string of hex bytes
     The string MUST contain valid hex characters
     Spaces or colons can be part of the bytes but will be discarded This can be used to create a custom protocol from other inputs such as scapy, wireshark, pcap etc
     An example of ethernet/ipv4: '00000000000200000000000108004500001400010000400066e70a0000010a000002'
    - patterns (list[BitPattern]): Modify the bytes with bit based patterns
    """
    def __init__(self, bytes=None, patterns=[]):
        if isinstance(bytes, (str)) is True:
            import re
            assert(bool(re.match(r'^[A-Fa-f0-9: ]+$', bytes)) is True)
            self.bytes = bytes
        else:
            raise TypeError('bytes must be an instance of (str)')
        if isinstance(patterns, (list, type(None))) is True:
            self.patterns = [] if patterns is None else list(patterns)
        else:
            raise TypeError('patterns must be an instance of (list, type(None))')


class BitPattern(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.BitPattern

    Container for a bit pattern  

    Args
    ----
    - choice (Union[BitList, BitCounter]): TBD
    """
    _CHOICE_MAP = {
        'BitList': 'bitlist',
        'BitCounter': 'bitcounter',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import BitList
        from abstract_open_traffic_generator.flow import BitCounter
        if isinstance(choice, (BitList, BitCounter)) is False:
            raise TypeError('choice must be of type: BitList, BitCounter')
        self.__setattr__('choice', BitPattern._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(BitPattern._CHOICE_MAP[type(choice).__name__], choice)


class BitList(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.BitList

    A pattern which is a list of values  

    Args
    ----
    - offset (int): Bit offset in the packet at which the pattern will be applied
    - length (int): The number of bits in the packet that the pattern will span
    - count (int): The number of values to generate before repeating
    - values (list[str]): TBD
    """
    def __init__(self, offset=1, length=1, count=1, values=[]):
        if isinstance(offset, (float, int, type(None))) is True:
            self.offset = offset
        else:
            raise TypeError('offset must be an instance of (float, int, type(None))')
        if isinstance(length, (float, int, type(None))) is True:
            self.length = length
        else:
            raise TypeError('length must be an instance of (float, int, type(None))')
        if isinstance(count, (float, int, type(None))) is True:
            self.count = count
        else:
            raise TypeError('count must be an instance of (float, int, type(None))')
        if isinstance(values, (list, type(None))) is True:
            self.values = [] if values is None else list(values)
        else:
            raise TypeError('values must be an instance of (list, type(None))')


class BitCounter(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.BitCounter

    An incrementing pattern  

    Args
    ----
    - offset (int): Bit offset in the packet at which the pattern will be applied
    - length (int): The number of bits in the packet that the pattern will span
    - count (int): The number of values to generate before repeating A value of 0 means the pattern will count continuously
    - start (str): The starting value of the pattern
     If the value is greater than the length it will be truncated
    - step (str): The amount the start value will be incremented by If the value is greater than the length it will be truncated
    """
    def __init__(self, offset=0, length=32, count=1, start='0', step='0'):
        if isinstance(offset, (float, int, type(None))) is True:
            self.offset = offset
        else:
            raise TypeError('offset must be an instance of (float, int, type(None))')
        if isinstance(length, (float, int, type(None))) is True:
            self.length = length
        else:
            raise TypeError('length must be an instance of (float, int, type(None))')
        if isinstance(count, (float, int, type(None))) is True:
            self.count = count
        else:
            raise TypeError('count must be an instance of (float, int, type(None))')
        if isinstance(start, (str, type(None))) is True:
            import re
            assert(bool(re.match(r'^[A-Fa-f0-9: ]+$', start)) is True)
            self.start = start
        else:
            raise TypeError('start must be an instance of (str, type(None))')
        if isinstance(step, (str, type(None))) is True:
            import re
            assert(bool(re.match(r'^[A-Fa-f0-9: ]+$', step)) is True)
            self.step = step
        else:
            raise TypeError('step must be an instance of (str, type(None))')


class Ethernet(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ethernet

    Ethernet packet header  

    Args
    ----
    - dst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - src (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - ether_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pfc_queue (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Optional field of 3 bits
    """
    def __init__(self, dst=None, src=None, ether_type=None, pfc_queue=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(dst, (Pattern, type(None))) is True:
            self.dst = dst
        else:
            raise TypeError('dst must be an instance of (Pattern, type(None))')
        if isinstance(src, (Pattern, type(None))) is True:
            self.src = src
        else:
            raise TypeError('src must be an instance of (Pattern, type(None))')
        if isinstance(ether_type, (Pattern, type(None))) is True:
            self.ether_type = ether_type
        else:
            raise TypeError('ether_type must be an instance of (Pattern, type(None))')
        if isinstance(pfc_queue, (Pattern, type(None))) is True:
            self.pfc_queue = pfc_queue
        else:
            raise TypeError('pfc_queue must be an instance of (Pattern, type(None))')


class Pattern(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Pattern

    A container for packet header field patterns  
    Possible patterns are fixed, list, counter, random  

    Args
    ----
    - choice (Union[str, list, Counter, Random]): TBD
    - ingress_result_name (str): A unique name is used to indicate to the system that the field may extend the result row key and create an aggregate result row for every unique ingress value
     To have ingress columns appear in flow result rows the flow result request allows for the ingress_result_name value to be specified as part of the request
    """
    _CHOICE_MAP = {
        'str': 'fixed',
        'list': 'list',
        'Counter': 'counter',
        'Random': 'random',
    }
    def __init__(self, choice=None, ingress_result_name=None):
        from abstract_open_traffic_generator.flow import Counter
        from abstract_open_traffic_generator.flow import Random
        if isinstance(choice, (str, list, Counter, Random)) is False:
            raise TypeError('choice must be of type: str, list, Counter, Random')
        self.__setattr__('choice', Pattern._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Pattern._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(ingress_result_name, (str, type(None))) is True:
            self.ingress_result_name = ingress_result_name
        else:
            raise TypeError('ingress_result_name must be an instance of (str, type(None))')


class Counter(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Counter

    A counter pattern that can increment or decrement  

    Args
    ----
    - start (str): The value at which the pattern will start
    - step (str): The value at which the pattern will increment or decrement by
    - count (Union[float, int]): The number of values in the pattern
    - up (Union[True, False]): Determines whether the pattern will increment (true) or decrement (false)
    """
    def __init__(self, start=None, step=None, count=None, up=True):
        if isinstance(start, (str, type(None))) is True:
            self.start = start
        else:
            raise TypeError('start must be an instance of (str, type(None))')
        if isinstance(step, (str, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (str, type(None))')
        if isinstance(count, (float, int, type(None))) is True:
            self.count = count
        else:
            raise TypeError('count must be an instance of (float, int, type(None))')
        if isinstance(up, (bool, type(None))) is True:
            self.up = up
        else:
            raise TypeError('up must be an instance of (bool, type(None))')


class Random(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Random

    A repeatable random range pattern  

    Args
    ----
    - min (str): TBD
    - max (str): TBD
    - step (Union[float, int]): TBD
    - seed (str): TBD
    - count (Union[float, int]): TBD
    """
    def __init__(self, min=None, max=None, step=None, seed=None, count=None):
        if isinstance(min, (str, type(None))) is True:
            self.min = min
        else:
            raise TypeError('min must be an instance of (str, type(None))')
        if isinstance(max, (str, type(None))) is True:
            self.max = max
        else:
            raise TypeError('max must be an instance of (str, type(None))')
        if isinstance(step, (float, int, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (float, int, type(None))')
        if isinstance(seed, (str, type(None))) is True:
            self.seed = seed
        else:
            raise TypeError('seed must be an instance of (str, type(None))')
        if isinstance(count, (float, int, type(None))) is True:
            self.count = count
        else:
            raise TypeError('count must be an instance of (float, int, type(None))')


class Vlan(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Vlan

    Vlan packet header  

    Args
    ----
    - priority (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - cfi (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - id (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - protocol (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    """
    def __init__(self, priority=None, cfi=None, id=None, protocol=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(priority, (Pattern, type(None))) is True:
            self.priority = priority
        else:
            raise TypeError('priority must be an instance of (Pattern, type(None))')
        if isinstance(cfi, (Pattern, type(None))) is True:
            self.cfi = cfi
        else:
            raise TypeError('cfi must be an instance of (Pattern, type(None))')
        if isinstance(id, (Pattern, type(None))) is True:
            self.id = id
        else:
            raise TypeError('id must be an instance of (Pattern, type(None))')
        if isinstance(protocol, (Pattern, type(None))) is True:
            self.protocol = protocol
        else:
            raise TypeError('protocol must be an instance of (Pattern, type(None))')


class Vxlan(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Vxlan

    Vxlan packet header  

    Args
    ----
    - flags (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     RRRRIRRR Where the I flag MUST be set to 1 for a valid vxlan network id (VNI)
     The other 7 bits (designated "R") are reserved fields and MUST be set to zero on transmission and ignored on receipt
     8 bits
    - reserved0 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Set to 0
     24 bits
    - vni (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Vxlan network id
     24 bits
    - reserved1 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Set to 0
     8 bits
    """
    def __init__(self, flags=None, reserved0=None, vni=None, reserved1=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(flags, (Pattern, type(None))) is True:
            self.flags = flags
        else:
            raise TypeError('flags must be an instance of (Pattern, type(None))')
        if isinstance(reserved0, (Pattern, type(None))) is True:
            self.reserved0 = reserved0
        else:
            raise TypeError('reserved0 must be an instance of (Pattern, type(None))')
        if isinstance(vni, (Pattern, type(None))) is True:
            self.vni = vni
        else:
            raise TypeError('vni must be an instance of (Pattern, type(None))')
        if isinstance(reserved1, (Pattern, type(None))) is True:
            self.reserved1 = reserved1
        else:
            raise TypeError('reserved1 must be an instance of (Pattern, type(None))')


class Ipv4(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ipv4

    Ipv4 packet header  

    Args
    ----
    - version (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - header_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - priority (Priority): A container for ipv4 raw, tos, dscp ip priorities
    - total_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - identification (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - reserved (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - dont_fragment (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - more_fragments (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - fragment_offset (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - time_to_live (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - protocol (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - header_checksum (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - src (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - dst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    """
    def __init__(self, version=None, header_length=None, priority=None, total_length=None, identification=None, reserved=None, dont_fragment=None, more_fragments=None, fragment_offset=None, time_to_live=None, protocol=None, header_checksum=None, src=None, dst=None):
        from abstract_open_traffic_generator.flow import Pattern
        from abstract_open_traffic_generator.flow_ipv4 import Priority
        if isinstance(version, (Pattern, type(None))) is True:
            self.version = version
        else:
            raise TypeError('version must be an instance of (Pattern, type(None))')
        if isinstance(header_length, (Pattern, type(None))) is True:
            self.header_length = header_length
        else:
            raise TypeError('header_length must be an instance of (Pattern, type(None))')
        if isinstance(priority, (Priority, type(None))) is True:
            self.priority = priority
        else:
            raise TypeError('priority must be an instance of (Priority, type(None))')
        if isinstance(total_length, (Pattern, type(None))) is True:
            self.total_length = total_length
        else:
            raise TypeError('total_length must be an instance of (Pattern, type(None))')
        if isinstance(identification, (Pattern, type(None))) is True:
            self.identification = identification
        else:
            raise TypeError('identification must be an instance of (Pattern, type(None))')
        if isinstance(reserved, (Pattern, type(None))) is True:
            self.reserved = reserved
        else:
            raise TypeError('reserved must be an instance of (Pattern, type(None))')
        if isinstance(dont_fragment, (Pattern, type(None))) is True:
            self.dont_fragment = dont_fragment
        else:
            raise TypeError('dont_fragment must be an instance of (Pattern, type(None))')
        if isinstance(more_fragments, (Pattern, type(None))) is True:
            self.more_fragments = more_fragments
        else:
            raise TypeError('more_fragments must be an instance of (Pattern, type(None))')
        if isinstance(fragment_offset, (Pattern, type(None))) is True:
            self.fragment_offset = fragment_offset
        else:
            raise TypeError('fragment_offset must be an instance of (Pattern, type(None))')
        if isinstance(time_to_live, (Pattern, type(None))) is True:
            self.time_to_live = time_to_live
        else:
            raise TypeError('time_to_live must be an instance of (Pattern, type(None))')
        if isinstance(protocol, (Pattern, type(None))) is True:
            self.protocol = protocol
        else:
            raise TypeError('protocol must be an instance of (Pattern, type(None))')
        if isinstance(header_checksum, (Pattern, type(None))) is True:
            self.header_checksum = header_checksum
        else:
            raise TypeError('header_checksum must be an instance of (Pattern, type(None))')
        if isinstance(src, (Pattern, type(None))) is True:
            self.src = src
        else:
            raise TypeError('src must be an instance of (Pattern, type(None))')
        if isinstance(dst, (Pattern, type(None))) is True:
            self.dst = dst
        else:
            raise TypeError('dst must be an instance of (Pattern, type(None))')


class Ipv6(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ipv6

    Ipv6 packet header  

    Args
    ----
    - version (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Default version number is 6 (bit sequence 0110) 4 bits
    - traffic_class (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     8 bits
    - flow_label (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     20 bits
    - payload_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     16 bits
    - next_header (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     8 bits
    - hop_limit (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     8 bits
    - src (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     128 bits
    - dst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     128 bits
    """
    def __init__(self, version=None, traffic_class=None, flow_label=None, payload_length=None, next_header=None, hop_limit=None, src=None, dst=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(version, (Pattern, type(None))) is True:
            self.version = version
        else:
            raise TypeError('version must be an instance of (Pattern, type(None))')
        if isinstance(traffic_class, (Pattern, type(None))) is True:
            self.traffic_class = traffic_class
        else:
            raise TypeError('traffic_class must be an instance of (Pattern, type(None))')
        if isinstance(flow_label, (Pattern, type(None))) is True:
            self.flow_label = flow_label
        else:
            raise TypeError('flow_label must be an instance of (Pattern, type(None))')
        if isinstance(payload_length, (Pattern, type(None))) is True:
            self.payload_length = payload_length
        else:
            raise TypeError('payload_length must be an instance of (Pattern, type(None))')
        if isinstance(next_header, (Pattern, type(None))) is True:
            self.next_header = next_header
        else:
            raise TypeError('next_header must be an instance of (Pattern, type(None))')
        if isinstance(hop_limit, (Pattern, type(None))) is True:
            self.hop_limit = hop_limit
        else:
            raise TypeError('hop_limit must be an instance of (Pattern, type(None))')
        if isinstance(src, (Pattern, type(None))) is True:
            self.src = src
        else:
            raise TypeError('src must be an instance of (Pattern, type(None))')
        if isinstance(dst, (Pattern, type(None))) is True:
            self.dst = dst
        else:
            raise TypeError('dst must be an instance of (Pattern, type(None))')


class PfcPause(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.PfcPause

    IEEE 802.1Qbb PFC Pause packet header  
    - dst: 01:80:C2:00:00:01 48bits - src: 48bits - ether_type: 0x8808 16bits - control_op_code: 0x0101 16bits - class_enable_vector: 16bits - pause_class_0: 0x0000 16bits - pause_class_1: 0x0000 16bits - pause_class_2: 0x0000 16bits - pause_class_3: 0x0000 16bits - pause_class_4: 0x0000 16bits - pause_class_5: 0x0000 16bits - pause_class_6: 0x0000 16bits - pause_class_7: 0x0000 16bits  

    Args
    ----
    - dst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - src (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - ether_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - control_op_code (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - class_enable_vector (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_0 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_1 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_2 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_3 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_4 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_5 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_6 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - pause_class_7 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    """
    def __init__(self, dst=None, src=None, ether_type=None, control_op_code=None, class_enable_vector=None, pause_class_0=None, pause_class_1=None, pause_class_2=None, pause_class_3=None, pause_class_4=None, pause_class_5=None, pause_class_6=None, pause_class_7=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(dst, (Pattern, type(None))) is True:
            self.dst = dst
        else:
            raise TypeError('dst must be an instance of (Pattern, type(None))')
        if isinstance(src, (Pattern, type(None))) is True:
            self.src = src
        else:
            raise TypeError('src must be an instance of (Pattern, type(None))')
        if isinstance(ether_type, (Pattern, type(None))) is True:
            self.ether_type = ether_type
        else:
            raise TypeError('ether_type must be an instance of (Pattern, type(None))')
        if isinstance(control_op_code, (Pattern, type(None))) is True:
            self.control_op_code = control_op_code
        else:
            raise TypeError('control_op_code must be an instance of (Pattern, type(None))')
        if isinstance(class_enable_vector, (Pattern, type(None))) is True:
            self.class_enable_vector = class_enable_vector
        else:
            raise TypeError('class_enable_vector must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_0, (Pattern, type(None))) is True:
            self.pause_class_0 = pause_class_0
        else:
            raise TypeError('pause_class_0 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_1, (Pattern, type(None))) is True:
            self.pause_class_1 = pause_class_1
        else:
            raise TypeError('pause_class_1 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_2, (Pattern, type(None))) is True:
            self.pause_class_2 = pause_class_2
        else:
            raise TypeError('pause_class_2 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_3, (Pattern, type(None))) is True:
            self.pause_class_3 = pause_class_3
        else:
            raise TypeError('pause_class_3 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_4, (Pattern, type(None))) is True:
            self.pause_class_4 = pause_class_4
        else:
            raise TypeError('pause_class_4 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_5, (Pattern, type(None))) is True:
            self.pause_class_5 = pause_class_5
        else:
            raise TypeError('pause_class_5 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_6, (Pattern, type(None))) is True:
            self.pause_class_6 = pause_class_6
        else:
            raise TypeError('pause_class_6 must be an instance of (Pattern, type(None))')
        if isinstance(pause_class_7, (Pattern, type(None))) is True:
            self.pause_class_7 = pause_class_7
        else:
            raise TypeError('pause_class_7 must be an instance of (Pattern, type(None))')


class EthernetPause(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.EthernetPause

    IEEE 802.3x Ethernet Pause packet header  
    - dst: 01:80:C2:00:00:01 48bits - src: 48bits - ether_type: 0x8808 16bits - control_op_code: 0x0001 16bits - time: 0x0000 16bits  

    Args
    ----
    - dst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - src (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - ether_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - control_op_code (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    - time (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
    """
    def __init__(self, dst=None, src=None, ether_type=None, control_op_code=None, time=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(dst, (Pattern, type(None))) is True:
            self.dst = dst
        else:
            raise TypeError('dst must be an instance of (Pattern, type(None))')
        if isinstance(src, (Pattern, type(None))) is True:
            self.src = src
        else:
            raise TypeError('src must be an instance of (Pattern, type(None))')
        if isinstance(ether_type, (Pattern, type(None))) is True:
            self.ether_type = ether_type
        else:
            raise TypeError('ether_type must be an instance of (Pattern, type(None))')
        if isinstance(control_op_code, (Pattern, type(None))) is True:
            self.control_op_code = control_op_code
        else:
            raise TypeError('control_op_code must be an instance of (Pattern, type(None))')
        if isinstance(time, (Pattern, type(None))) is True:
            self.time = time
        else:
            raise TypeError('time must be an instance of (Pattern, type(None))')


class Tcp(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Tcp

    Tcp packet header  

    Args
    ----
    - src_port (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Tcp source port
     Max length is 2 bytes
    - dst_port (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Tcp destination port
     Max length is 2 bytes
    - ecn_ns (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Explicit congestion notification, concealment protection
     Max length is 1 bit
    - ecn_cwr (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Explicit congestion notification, congestion window reduced
     Max length is 1 bit
    - ecn_echo (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Explicit congestion notification, echo
     1 indicates the peer is ecn capable
     0 indicates that a packet with ipv4
     ecn = 11 in the ip header was received during normal transmission
     Max length is 1 bit
    - ctl_urg (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     The urgent pointer field is significant
     Max length is 1 bit
    - ctl_ack (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     The ackknowledgment field is significant
     Max length is 1 bit
    - ctl_psh (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Asks to push the buffered data to the receiving application
     Max length is 1 bit
    - ctl_rst (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Reset the connection
     Max length is 1 bit
    - ctl_syn (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Synchronize sequenece numbers
     Max length is 1 bit
    - ctl_fin (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Last packet from the sender
     Max length is 1 bit
    """
    def __init__(self, src_port=None, dst_port=None, ecn_ns=None, ecn_cwr=None, ecn_echo=None, ctl_urg=None, ctl_ack=None, ctl_psh=None, ctl_rst=None, ctl_syn=None, ctl_fin=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(src_port, (Pattern, type(None))) is True:
            self.src_port = src_port
        else:
            raise TypeError('src_port must be an instance of (Pattern, type(None))')
        if isinstance(dst_port, (Pattern, type(None))) is True:
            self.dst_port = dst_port
        else:
            raise TypeError('dst_port must be an instance of (Pattern, type(None))')
        if isinstance(ecn_ns, (Pattern, type(None))) is True:
            self.ecn_ns = ecn_ns
        else:
            raise TypeError('ecn_ns must be an instance of (Pattern, type(None))')
        if isinstance(ecn_cwr, (Pattern, type(None))) is True:
            self.ecn_cwr = ecn_cwr
        else:
            raise TypeError('ecn_cwr must be an instance of (Pattern, type(None))')
        if isinstance(ecn_echo, (Pattern, type(None))) is True:
            self.ecn_echo = ecn_echo
        else:
            raise TypeError('ecn_echo must be an instance of (Pattern, type(None))')
        if isinstance(ctl_urg, (Pattern, type(None))) is True:
            self.ctl_urg = ctl_urg
        else:
            raise TypeError('ctl_urg must be an instance of (Pattern, type(None))')
        if isinstance(ctl_ack, (Pattern, type(None))) is True:
            self.ctl_ack = ctl_ack
        else:
            raise TypeError('ctl_ack must be an instance of (Pattern, type(None))')
        if isinstance(ctl_psh, (Pattern, type(None))) is True:
            self.ctl_psh = ctl_psh
        else:
            raise TypeError('ctl_psh must be an instance of (Pattern, type(None))')
        if isinstance(ctl_rst, (Pattern, type(None))) is True:
            self.ctl_rst = ctl_rst
        else:
            raise TypeError('ctl_rst must be an instance of (Pattern, type(None))')
        if isinstance(ctl_syn, (Pattern, type(None))) is True:
            self.ctl_syn = ctl_syn
        else:
            raise TypeError('ctl_syn must be an instance of (Pattern, type(None))')
        if isinstance(ctl_fin, (Pattern, type(None))) is True:
            self.ctl_fin = ctl_fin
        else:
            raise TypeError('ctl_fin must be an instance of (Pattern, type(None))')


class Udp(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Udp

    Udp packet header  

    Args
    ----
    - src_port (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Udp source port
     Max length is 2 bytes
    - dst_port (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Tcp destination port
     Max length is 2 bytes
    - length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Length in bytes of the udp header and yudp data
     Max length is 2 bytes
    - checksum (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Checksum field used for error checking of header and data
     Max length is 2 bytes
    """
    def __init__(self, src_port=None, dst_port=None, length=None, checksum=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(src_port, (Pattern, type(None))) is True:
            self.src_port = src_port
        else:
            raise TypeError('src_port must be an instance of (Pattern, type(None))')
        if isinstance(dst_port, (Pattern, type(None))) is True:
            self.dst_port = dst_port
        else:
            raise TypeError('dst_port must be an instance of (Pattern, type(None))')
        if isinstance(length, (Pattern, type(None))) is True:
            self.length = length
        else:
            raise TypeError('length must be an instance of (Pattern, type(None))')
        if isinstance(checksum, (Pattern, type(None))) is True:
            self.checksum = checksum
        else:
            raise TypeError('checksum must be an instance of (Pattern, type(None))')


class Gre(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Gre

    Gre packet header  

    Args
    ----
    - checksum_present (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Checksum bit
     Set to 1 if a checksum is present
    - key_present (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Key bit
     Set to 1 if a key is present
    - seq_number_present (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Sequence number bit
     Set to 1 if a sequence number is present
    - reserved0 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Reserved bits
     Set to 0
     9 bits
    - version (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Gre version number
     Set to 0
     3 bits
    - protocol (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Indicates the ether protocol type of the encapsulated payload
     - 0x0800 ipv4 - 0x86DD ipv6
    - checksum (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Present if the checksum_present bit is set
     Contains the checksum for the gre header and payload
     16 bits
    - reserved1 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Reserved bits
     Set to 0
     16 bits
    - key (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Present if the key_present bit is set
     Contains an application specific key value
     32 bits
    - sequence_number (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Present if the seq_number_present bit is set
     Contains a sequence number for the gre packet
     32 bits
    """
    def __init__(self, checksum_present=None, key_present=None, seq_number_present=None, reserved0=None, version=None, protocol=None, checksum=None, reserved1=None, key=None, sequence_number=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(checksum_present, (Pattern, type(None))) is True:
            self.checksum_present = checksum_present
        else:
            raise TypeError('checksum_present must be an instance of (Pattern, type(None))')
        if isinstance(key_present, (Pattern, type(None))) is True:
            self.key_present = key_present
        else:
            raise TypeError('key_present must be an instance of (Pattern, type(None))')
        if isinstance(seq_number_present, (Pattern, type(None))) is True:
            self.seq_number_present = seq_number_present
        else:
            raise TypeError('seq_number_present must be an instance of (Pattern, type(None))')
        if isinstance(reserved0, (Pattern, type(None))) is True:
            self.reserved0 = reserved0
        else:
            raise TypeError('reserved0 must be an instance of (Pattern, type(None))')
        if isinstance(version, (Pattern, type(None))) is True:
            self.version = version
        else:
            raise TypeError('version must be an instance of (Pattern, type(None))')
        if isinstance(protocol, (Pattern, type(None))) is True:
            self.protocol = protocol
        else:
            raise TypeError('protocol must be an instance of (Pattern, type(None))')
        if isinstance(checksum, (Pattern, type(None))) is True:
            self.checksum = checksum
        else:
            raise TypeError('checksum must be an instance of (Pattern, type(None))')
        if isinstance(reserved1, (Pattern, type(None))) is True:
            self.reserved1 = reserved1
        else:
            raise TypeError('reserved1 must be an instance of (Pattern, type(None))')
        if isinstance(key, (Pattern, type(None))) is True:
            self.key = key
        else:
            raise TypeError('key must be an instance of (Pattern, type(None))')
        if isinstance(sequence_number, (Pattern, type(None))) is True:
            self.sequence_number = sequence_number
        else:
            raise TypeError('sequence_number must be an instance of (Pattern, type(None))')


class Gtpv1(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Gtpv1

    GTPv1 packet header  

    Args
    ----
    - version (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     It is a 3-bit field
     For GTPv1, this has a value of 1
    - protocol_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 1-bit value that differentiates GTP (value 1) from GTP' (value 0)
    - reserved (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 1-bit reserved field (must be 0)
    - e_flag (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 1-bit value that states whether there is an extension header optional field
    - s_flag (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 1-bit value that states whether there is a Sequence Number optional field
    - pn_flag (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 1-bit value that states whether there is a N-PDU number optional field
    - message_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An 8-bit field that indicates the type of GTP message
     Different types of messages are defined in 3GPP TS 29
     060 section 7
     1
    - message_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 16-bit field that indicates the length of the payload in bytes (rest of the packet following the mandatory 8-byte GTP header)
     Includes the optional fields
    - teid (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Tunnel endpoint identifier
     A 32-bit(4-octet) field used to multiplex different connections in the same GTP tunnel
    - squence_number (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An (optional) 16-bit field
     This field exists if any of the e_flag, s_flag, or pn_flag bits are on
     The field must be interpreted only if the s_flag bit is on
    - n_pdu_number (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An (optional) 8-bit field
     This field exists if any of the e_flag, s_flag, or pn_flag bits are on
     The field must be interpreted only if the pn_flag bit is on
    - next_extension_header_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An (optional) 8-bit field
     This field exists if any of the e_flag, s_flag, or pn_flag bits are on
     The field must be interpreted only if the e_flag bit is on
    - extension_headers (list[GtpExtension]): A list of optional extension headers
    """
    def __init__(self, version=None, protocol_type=None, reserved=None, e_flag=None, s_flag=None, pn_flag=None, message_type=None, message_length=None, teid=None, squence_number=None, n_pdu_number=None, next_extension_header_type=None, extension_headers=[]):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(version, (Pattern, type(None))) is True:
            self.version = version
        else:
            raise TypeError('version must be an instance of (Pattern, type(None))')
        if isinstance(protocol_type, (Pattern, type(None))) is True:
            self.protocol_type = protocol_type
        else:
            raise TypeError('protocol_type must be an instance of (Pattern, type(None))')
        if isinstance(reserved, (Pattern, type(None))) is True:
            self.reserved = reserved
        else:
            raise TypeError('reserved must be an instance of (Pattern, type(None))')
        if isinstance(e_flag, (Pattern, type(None))) is True:
            self.e_flag = e_flag
        else:
            raise TypeError('e_flag must be an instance of (Pattern, type(None))')
        if isinstance(s_flag, (Pattern, type(None))) is True:
            self.s_flag = s_flag
        else:
            raise TypeError('s_flag must be an instance of (Pattern, type(None))')
        if isinstance(pn_flag, (Pattern, type(None))) is True:
            self.pn_flag = pn_flag
        else:
            raise TypeError('pn_flag must be an instance of (Pattern, type(None))')
        if isinstance(message_type, (Pattern, type(None))) is True:
            self.message_type = message_type
        else:
            raise TypeError('message_type must be an instance of (Pattern, type(None))')
        if isinstance(message_length, (Pattern, type(None))) is True:
            self.message_length = message_length
        else:
            raise TypeError('message_length must be an instance of (Pattern, type(None))')
        if isinstance(teid, (Pattern, type(None))) is True:
            self.teid = teid
        else:
            raise TypeError('teid must be an instance of (Pattern, type(None))')
        if isinstance(squence_number, (Pattern, type(None))) is True:
            self.squence_number = squence_number
        else:
            raise TypeError('squence_number must be an instance of (Pattern, type(None))')
        if isinstance(n_pdu_number, (Pattern, type(None))) is True:
            self.n_pdu_number = n_pdu_number
        else:
            raise TypeError('n_pdu_number must be an instance of (Pattern, type(None))')
        if isinstance(next_extension_header_type, (Pattern, type(None))) is True:
            self.next_extension_header_type = next_extension_header_type
        else:
            raise TypeError('next_extension_header_type must be an instance of (Pattern, type(None))')
        if isinstance(extension_headers, (list, type(None))) is True:
            self.extension_headers = [] if extension_headers is None else list(extension_headers)
        else:
            raise TypeError('extension_headers must be an instance of (list, type(None))')


class GtpExtension(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.GtpExtension

    TBD  

    Args
    ----
    - extension_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An 8-bit field
     This field states the length of this extension header, including the length, the contents, and the next extension header field, in 4-octet units, so the length of the extension must always be a multiple of 4
    - contents (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     The extension header contents
    - next_extension_header (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An 8-bit field
     It states the type of the next extension, or 0 if no next extension exists
     This permits chaining several next extension headers
    """
    def __init__(self, extension_length=None, contents=None, next_extension_header=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(extension_length, (Pattern, type(None))) is True:
            self.extension_length = extension_length
        else:
            raise TypeError('extension_length must be an instance of (Pattern, type(None))')
        if isinstance(contents, (Pattern, type(None))) is True:
            self.contents = contents
        else:
            raise TypeError('contents must be an instance of (Pattern, type(None))')
        if isinstance(next_extension_header, (Pattern, type(None))) is True:
            self.next_extension_header = next_extension_header
        else:
            raise TypeError('next_extension_header must be an instance of (Pattern, type(None))')


class Gtpv2(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Gtpv2

    GTPv2 packet header  

    Args
    ----
    - version (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     It is a 3-bit field
     For GTPv2, this has a value of 2
    - piggybacking_flag (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     If this bit is set to 1 then another GTP-C message with its own header shall be present at the end of the current message
    - teid_flag (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     If this bit is set to 1 then the TEID field will be present between the message length and the sequence number
     All messages except Echo and Echo reply require TEID to be present
    - spare1 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 3-bit reserved field (must be 0)
    - message_type (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An 8-bit field that indicates the type of GTP message
     Different types of messages are defined in 3GPP TS 29
     060 section 7
     1
    - message_length (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 16-bit field that indicates the length of the payload in bytes (excluding the mandatory GTP-c header (first 4 bytes)
     Includes the TEID and sequence_number if they are present
    - teid (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Tunnel endpoint identifier
     A 32-bit (4-octet) field used to multiplex different connections in the same GTP tunnel
     Is present only if the teid_flag is set
    - sequence_number (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     A 24-bit field
    - spare2 (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     An 8-bit reserved field (must be 0)
    """
    def __init__(self, version=None, piggybacking_flag=None, teid_flag=None, spare1=None, message_type=None, message_length=None, teid=None, sequence_number=None, spare2=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(version, (Pattern, type(None))) is True:
            self.version = version
        else:
            raise TypeError('version must be an instance of (Pattern, type(None))')
        if isinstance(piggybacking_flag, (Pattern, type(None))) is True:
            self.piggybacking_flag = piggybacking_flag
        else:
            raise TypeError('piggybacking_flag must be an instance of (Pattern, type(None))')
        if isinstance(teid_flag, (Pattern, type(None))) is True:
            self.teid_flag = teid_flag
        else:
            raise TypeError('teid_flag must be an instance of (Pattern, type(None))')
        if isinstance(spare1, (Pattern, type(None))) is True:
            self.spare1 = spare1
        else:
            raise TypeError('spare1 must be an instance of (Pattern, type(None))')
        if isinstance(message_type, (Pattern, type(None))) is True:
            self.message_type = message_type
        else:
            raise TypeError('message_type must be an instance of (Pattern, type(None))')
        if isinstance(message_length, (Pattern, type(None))) is True:
            self.message_length = message_length
        else:
            raise TypeError('message_length must be an instance of (Pattern, type(None))')
        if isinstance(teid, (Pattern, type(None))) is True:
            self.teid = teid
        else:
            raise TypeError('teid must be an instance of (Pattern, type(None))')
        if isinstance(sequence_number, (Pattern, type(None))) is True:
            self.sequence_number = sequence_number
        else:
            raise TypeError('sequence_number must be an instance of (Pattern, type(None))')
        if isinstance(spare2, (Pattern, type(None))) is True:
            self.spare2 = spare2
        else:
            raise TypeError('spare2 must be an instance of (Pattern, type(None))')


class Size(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Size

    The frame size which overrides the total length of the packet  

    Args
    ----
    - choice (Union[float, int, SizeIncrement, SizeRandom]): TBD
    """
    _CHOICE_MAP = {
        'float': 'fixed',
        'int': 'fixed',
        'SizeIncrement': 'increment',
        'SizeRandom': 'random',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import SizeIncrement
        from abstract_open_traffic_generator.flow import SizeRandom
        if isinstance(choice, (float, int, SizeIncrement, SizeRandom)) is False:
            raise TypeError('choice must be of type: float, int, SizeIncrement, SizeRandom')
        self.__setattr__('choice', Size._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Size._CHOICE_MAP[type(choice).__name__], choice)


class SizeIncrement(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.SizeIncrement

    Frame size that increments from a starting size to an ending size incrementing by a step size  

    Args
    ----
    - start (int): Starting frame size in bytes
    - end (int): Ending frame size in bytes
    - step (int): Step frame size in bytes
    """
    def __init__(self, start=64, end=1518, step=1):
        if isinstance(start, (float, int)) is True:
            self.start = start
        else:
            raise TypeError('start must be an instance of (float, int)')
        if isinstance(end, (float, int)) is True:
            self.end = end
        else:
            raise TypeError('end must be an instance of (float, int)')
        if isinstance(step, (float, int)) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (float, int)')


class SizeRandom(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.SizeRandom

    Random frame size from a min value to a max value  

    Args
    ----
    - min (int): TBD
    - max (int): TBD
    """
    def __init__(self, min=64, max=1518):
        if isinstance(min, (float, int)) is True:
            self.min = min
        else:
            raise TypeError('min must be an instance of (float, int)')
        if isinstance(max, (float, int)) is True:
            self.max = max
        else:
            raise TypeError('max must be an instance of (float, int)')


class Rate(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Rate

    The rate of packet transmission  

    Args
    ----
    - unit (Union[pps, bps, kbps, mbps, gbps, line]): The value is a unit of this
    - value (int): The actual rate
    """
    def __init__(self, unit=None, value=None):
        if isinstance(unit, (str)) is True:
            self.unit = unit
        else:
            raise TypeError('unit must be an instance of (str)')
        if isinstance(value, (float, int)) is True:
            self.value = value
        else:
            raise TypeError('value must be an instance of (float, int)')


class Duration(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Duration

    A container for different transmit durations  

    Args
    ----
    - choice (Union[FixedPackets, FixedSeconds, Burst, Continuous]): TBD
    """
    _CHOICE_MAP = {
        'FixedPackets': 'packets',
        'FixedSeconds': 'seconds',
        'Burst': 'burst',
        'Continuous': 'continuous',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import FixedPackets
        from abstract_open_traffic_generator.flow import FixedSeconds
        from abstract_open_traffic_generator.flow import Burst
        from abstract_open_traffic_generator.flow import Continuous
        if isinstance(choice, (FixedPackets, FixedSeconds, Burst, Continuous)) is False:
            raise TypeError('choice must be of type: FixedPackets, FixedSeconds, Burst, Continuous')
        self.__setattr__('choice', Duration._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Duration._CHOICE_MAP[type(choice).__name__], choice)


class Continuous(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Continuous

    Transmit will be continuous and will not stop automatically  

    Args
    ----
    - gap (int): The minimum gap between packets expressed as bytes
    - delay (int): The delay before starting transmission of packets
    - delay_unit (Union[bytes, nanoseconds]): The delay expressed as a number of this value
    """
    def __init__(self, gap=12, delay=0, delay_unit='bytes'):
        if isinstance(gap, (float, int, type(None))) is True:
            self.gap = gap
        else:
            raise TypeError('gap must be an instance of (float, int, type(None))')
        if isinstance(delay, (float, int, type(None))) is True:
            self.delay = delay
        else:
            raise TypeError('delay must be an instance of (float, int, type(None))')
        if isinstance(delay_unit, (str, type(None))) is True:
            self.delay_unit = delay_unit
        else:
            raise TypeError('delay_unit must be an instance of (str, type(None))')


class FixedPackets(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.FixedPackets

    Transmit a fixed number of packets after which the flow will stop  

    Args
    ----
    - packets (int): Stop transmit of the flow after this number of packets
    - gap (int): The minimum gap between packets expressed as bytes
    - delay (int): The delay before starting transmission of packets
    - delay_unit (Union[bytes, nanoseconds]): The delay expressed as a number of this value
    """
    def __init__(self, packets=1, gap=12, delay=0, delay_unit='bytes'):
        if isinstance(packets, (float, int, type(None))) is True:
            self.packets = packets
        else:
            raise TypeError('packets must be an instance of (float, int, type(None))')
        if isinstance(gap, (float, int, type(None))) is True:
            self.gap = gap
        else:
            raise TypeError('gap must be an instance of (float, int, type(None))')
        if isinstance(delay, (float, int, type(None))) is True:
            self.delay = delay
        else:
            raise TypeError('delay must be an instance of (float, int, type(None))')
        if isinstance(delay_unit, (str, type(None))) is True:
            self.delay_unit = delay_unit
        else:
            raise TypeError('delay_unit must be an instance of (str, type(None))')


class FixedSeconds(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.FixedSeconds

    Transmit for a fixed number of seconds after which the flow will stop  

    Args
    ----
    - seconds (Union[float, int]): Stop transmit of the flow after this number of seconds
    - gap (int): The minimum gap between packets expressed as bytes
    - delay (int): The delay before starting transmission of packets
    - delay_unit (Union[bytes, nanoseconds]): The delay expressed as a number of this value
    """
    def __init__(self, seconds=1, gap=12, delay=0, delay_unit='bytes'):
        if isinstance(seconds, (float, int, type(None))) is True:
            self.seconds = seconds
        else:
            raise TypeError('seconds must be an instance of (float, int, type(None))')
        if isinstance(gap, (float, int, type(None))) is True:
            self.gap = gap
        else:
            raise TypeError('gap must be an instance of (float, int, type(None))')
        if isinstance(delay, (float, int, type(None))) is True:
            self.delay = delay
        else:
            raise TypeError('delay must be an instance of (float, int, type(None))')
        if isinstance(delay_unit, (str, type(None))) is True:
            self.delay_unit = delay_unit
        else:
            raise TypeError('delay_unit must be an instance of (str, type(None))')


class Burst(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Burst

    A continuous burst of packets that will not automatically stop  

    Args
    ----
    - packets (int): The number of packets transmitted per burst
    - gap (int): The minimum gap between packets expressed as bytes
    - inter_burst_gap (int): The gap between the transmission of each burst
     A value of 0 means there is no gap between bursts
    - inter_burst_gap_unit (Union[bytes, nanoseconds]): The inter burst gap expressed as a number of this value
    """
    def __init__(self, packets=None, gap=12, inter_burst_gap=0, inter_burst_gap_unit='bytes'):
        if isinstance(packets, (float, int, type(None))) is True:
            self.packets = packets
        else:
            raise TypeError('packets must be an instance of (float, int, type(None))')
        if isinstance(gap, (float, int, type(None))) is True:
            self.gap = gap
        else:
            raise TypeError('gap must be an instance of (float, int, type(None))')
        if isinstance(inter_burst_gap, (float, int, type(None))) is True:
            self.inter_burst_gap = inter_burst_gap
        else:
            raise TypeError('inter_burst_gap must be an instance of (float, int, type(None))')
        if isinstance(inter_burst_gap_unit, (str, type(None))) is True:
            self.inter_burst_gap_unit = inter_burst_gap_unit
        else:
            raise TypeError('inter_burst_gap_unit must be an instance of (str, type(None))')





class Port(object):
    """Generated from OpenAPI schema object #/components/schemas/Port

    An abstract test port  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - location (str): The location of a test port
     It is the endpoint where packets will emit from
     Test port locations can be the following: - physical appliance with multiple ports - physical chassis with multiple cards and ports - local interface - virtual machine, docker container, kubernetes cluster The test port location format is implementation specific
     Use the /results/capabilities API to determine what formats an implementation supports for the location property
     Get the configured location state by using the /results/port API
    """
    def __init__(self, name=None, location=None):
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(location, (str, type(None))) is True:
            self.location = location
        else:
            raise TypeError('location must be an instance of (str, type(None))')


class Options(object):
    """Generated from OpenAPI schema object #/components/schemas/Port.Options

    Common port options that apply to all configured Port.Port objects  

    Args
    ----
    - location_preemption (Union[True, False]): Preempt all the test port locations as defined by the Port
     Port
     properties
     location
     If the test ports as defined by their location values are in use and this value is true, the test ports will be preempted
    """
    def __init__(self, location_preemption=False):
        if isinstance(location_preemption, (bool, type(None))) is True:
            self.location_preemption = location_preemption
        else:
            raise TypeError('location_preemption must be an instance of (bool, type(None))')



import pytest
from abstract_open_traffic_generator.config import Config
from abstract_open_traffic_generator.port import Port
from abstract_open_traffic_generator.capture import *


def test_capture(serializer):
    """Demonstrate how to specify capture settings for a configuration
    """
    config = Config()
    config.ports.append(Port(name='port1'))
    capture = Capture(name='capture1',
                      port_names=[config.ports[0].name],
                      choice=[
                          BasicFilter(
                              MacAddressFilter('source',
                                               filter='000000000000'))
                      ])
    config.captures.append(capture)
    print(serializer.json(config))


if __name__ == '__main__':
    pytest.main(['-s', __file__])



import pytest
from abstract_open_traffic_generator.config import Config, Options
from abstract_open_traffic_generator.port import Options as PortOptions


def test_config(serializer, tx, rx, port_ipv4_traffic):
    config = Config(ports=[tx], flows=[port_ipv4_traffic])
    print(serializer.json(config))

def test_config_options(serializer):
    options = Options(PortOptions(location_preemption=True))
    config = Config(options=options)
    print(serializer.json(config))


if __name__ == '__main__':
    pytest.main(['-s', __file__])





class Priority(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ipv4.Priority

    A container for ipv4 raw, tos, dscp ip priorities  

    Args
    ----
    - choice (Union[Pattern, Tos, Dscp]): TBD
    """
    
    PRIORITY_RAW = '0'
    
    _CHOICE_MAP = {
        'Pattern': 'raw',
        'Tos': 'tos',
        'Dscp': 'dscp',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.flow import Pattern
        from abstract_open_traffic_generator.flow_ipv4 import Tos
        from abstract_open_traffic_generator.flow_ipv4 import Dscp
        if isinstance(choice, (Pattern, Tos, Dscp)) is False:
            raise TypeError('choice must be of type: Pattern, Tos, Dscp')
        self.__setattr__('choice', Priority._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Priority._CHOICE_MAP[type(choice).__name__], choice)


class Dscp(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ipv4.Dscp

    Differentiated services code point (DSCP) packet field  

    Args
    ----
    - phb (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     phb (per-hop-behavior) value is 6 bits: >=0 PHB <=63
    - ecn (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     ecn (explicit-congestion-notification) value is 2 bits: >=0 ecn <=3
    """
    
    PHB_DEFAULT = '0'
    PHB_CS1 = '8'
    PHB_CS2 = '16'
    PHB_CS3 = '24'
    PHB_CS4 = '32'
    PHB_CS5 = '40'
    PHB_CS6 = '48'
    PHB_CS7 = '56'
    PHB_AF11 = '10'
    PHB_AF12 = '12'
    PHB_AF13 = '14'
    PHB_AF21 = '18'
    PHB_AF22 = '20'
    PHB_AF23 = '22'
    PHB_AF31 = '26'
    PHB_AF32 = '28'
    PHB_AF33 = '30'
    PHB_AF41 = '24'
    PHB_AF42 = '36'
    PHB_AF43 = '38'
    PHB_EF46 = '46'
    ECN_NON_CAPABLE = '0'
    ECN_CAPABLE_TRANSPORT_0 = '1'
    ECN_CAPABLE_TRANSPORT_1 = '2'
    ECN_CONGESTION_ENCOUNTERED = '3'
    
    def __init__(self, phb=None, ecn=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(phb, (Pattern, type(None))) is True:
            self.phb = phb
        else:
            raise TypeError('phb must be an instance of (Pattern, type(None))')
        if isinstance(ecn, (Pattern, type(None))) is True:
            self.ecn = ecn
        else:
            raise TypeError('ecn must be an instance of (Pattern, type(None))')


class Tos(object):
    """Generated from OpenAPI schema object #/components/schemas/Flow.Ipv4.Tos

    Type of service (TOS) packet field  

    Args
    ----
    - precedence (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Precedence value is 3 bits: >=0 precedence <=3
    - delay (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Delay value is 1 bit: >=0 delay <=1
    - throughput (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Throughput value is 1 bit: >=0 throughput <=3
    - reliability (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Reliability value is 1 bit: >=0 reliability <=1
    - monetary (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Monetary value is 1 bit: >=0 monetary <=1
    - unused (Pattern): A container for packet header field patterns
     Possible patterns are fixed, list, counter, random
     Unused value is 1 bit: >=0 unused <=1
    """
    
    PRE_ROUTINE = '0'
    PRE_PRIORITY = '1'
    PRE_IMMEDIATE = '2'
    PRE_FLASH = '3'
    PRE_FLASH_OVERRIDE = '4'
    PRE_CRITIC_ECP = '5'
    PRE_INTERNETWORK_CONTROL = '6'
    PRE_NETWORK_CONTROL = '7'
    NORMAL = '0'
    LOW = '1'
    
    def __init__(self, precedence=None, delay=None, throughput=None, reliability=None, monetary=None, unused=None):
        from abstract_open_traffic_generator.flow import Pattern
        if isinstance(precedence, (Pattern, type(None))) is True:
            self.precedence = precedence
        else:
            raise TypeError('precedence must be an instance of (Pattern, type(None))')
        if isinstance(delay, (Pattern, type(None))) is True:
            self.delay = delay
        else:
            raise TypeError('delay must be an instance of (Pattern, type(None))')
        if isinstance(throughput, (Pattern, type(None))) is True:
            self.throughput = throughput
        else:
            raise TypeError('throughput must be an instance of (Pattern, type(None))')
        if isinstance(reliability, (Pattern, type(None))) is True:
            self.reliability = reliability
        else:
            raise TypeError('reliability must be an instance of (Pattern, type(None))')
        if isinstance(monetary, (Pattern, type(None))) is True:
            self.monetary = monetary
        else:
            raise TypeError('monetary must be an instance of (Pattern, type(None))')
        if isinstance(unused, (Pattern, type(None))) is True:
            self.unused = unused
        else:
            raise TypeError('unused must be an instance of (Pattern, type(None))')





class Layer1(object):
    """Generated from OpenAPI schema object #/components/schemas/Layer1

    A container for layer1 settings  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - port_names (list[str]): A list of unique names of port objects that will share the choice settings
    - speed (Union[speed_10_fd_mbps, speed_10_hd_mbps, speed_100_fd_mbps, speed_100_hd_mbps, speed_1_gbps, speed_10_gbps, speed_25_gbps, speed_40_gbps, speed_100_gbps, speed_200_gbps, speed_400_gbps]): Set the speed if supported
    - media (Union[copper, fiber, sgmii]): Set the type of media interface if supported
    - promiscuous (Union[True, False]): Enable promiscuous mode if supported
    - mtu (int): Set the maximum transmission unit size if supported
    - ieee_media_defaults (Union[True, False]): Set to true to override the auto_negotiate, link_training and rs_fec settings for gigabit ethernet interfaces
    - auto_negotiate (Union[True, False]): Enable/disable auto negotiation
    - auto_negotiation (AutoNegotiation): Container for auto negotiation settings
    - flow_control (FlowControl): A container for layer1 receive flow control settings
     To enable flow control settings on ports this object must be a valid object not a null value
    """
    def __init__(self, name=None, port_names=[], speed='speed_10_gbps', media=None, promiscuous=False, mtu=1500, ieee_media_defaults=True, auto_negotiate=True, auto_negotiation=None, flow_control=None):
        from abstract_open_traffic_generator.layer1 import AutoNegotiation
        from abstract_open_traffic_generator.layer1 import FlowControl
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(port_names, (list)) is True:
            self.port_names = port_names
        else:
            raise TypeError('port_names must be an instance of (list)')
        if isinstance(speed, (str, type(None))) is True:
            self.speed = speed
        else:
            raise TypeError('speed must be an instance of (str, type(None))')
        if isinstance(media, (str, type(None))) is True:
            self.media = media
        else:
            raise TypeError('media must be an instance of (str, type(None))')
        if isinstance(promiscuous, (bool, type(None))) is True:
            self.promiscuous = promiscuous
        else:
            raise TypeError('promiscuous must be an instance of (bool, type(None))')
        if isinstance(mtu, (float, int, type(None))) is True:
            self.mtu = mtu
        else:
            raise TypeError('mtu must be an instance of (float, int, type(None))')
        if isinstance(ieee_media_defaults, (bool, type(None))) is True:
            self.ieee_media_defaults = ieee_media_defaults
        else:
            raise TypeError('ieee_media_defaults must be an instance of (bool, type(None))')
        if isinstance(auto_negotiate, (bool, type(None))) is True:
            self.auto_negotiate = auto_negotiate
        else:
            raise TypeError('auto_negotiate must be an instance of (bool, type(None))')
        if isinstance(auto_negotiation, (AutoNegotiation, type(None))) is True:
            self.auto_negotiation = auto_negotiation
        else:
            raise TypeError('auto_negotiation must be an instance of (AutoNegotiation, type(None))')
        if isinstance(flow_control, (FlowControl, type(None))) is True:
            self.flow_control = flow_control
        else:
            raise TypeError('flow_control must be an instance of (FlowControl, type(None))')


class AutoNegotiation(object):
    """Generated from OpenAPI schema object #/components/schemas/Layer1.AutoNegotiation

    Container for auto negotiation settings  

    Args
    ----
    - advertise_1000_mbps (Union[True, False]): If auto_negotiate is true and the interface supports this option then this speed will be advertised
    - advertise_100_fd_mbps (Union[True, False]): If auto_negotiate is true and the interface supports this option then this speed will be advertised
    - advertise_100_hd_mbps (Union[True, False]): If auto_negotiate is true and the interface supports this option then this speed will be advertised
    - advertise_10_fd_mbps (Union[True, False]): If auto_negotiate is true and the interface supports this option then this speed will be advertised
    - advertise_10_hd_mbps (Union[True, False]): If auto_negotiate is true and the interface supports this option then this speed will be advertised
    - link_training (Union[True, False]): Enable/disable gigabit ethernet link training
    - rs_fec (Union[True, False]): Enable/disable gigabit ethernet reed solomon forward error correction (RS FEC)
    """
    def __init__(self, advertise_1000_mbps=True, advertise_100_fd_mbps=True, advertise_100_hd_mbps=True, advertise_10_fd_mbps=True, advertise_10_hd_mbps=True, link_training=False, rs_fec=False):
        if isinstance(advertise_1000_mbps, (bool, type(None))) is True:
            self.advertise_1000_mbps = advertise_1000_mbps
        else:
            raise TypeError('advertise_1000_mbps must be an instance of (bool, type(None))')
        if isinstance(advertise_100_fd_mbps, (bool, type(None))) is True:
            self.advertise_100_fd_mbps = advertise_100_fd_mbps
        else:
            raise TypeError('advertise_100_fd_mbps must be an instance of (bool, type(None))')
        if isinstance(advertise_100_hd_mbps, (bool, type(None))) is True:
            self.advertise_100_hd_mbps = advertise_100_hd_mbps
        else:
            raise TypeError('advertise_100_hd_mbps must be an instance of (bool, type(None))')
        if isinstance(advertise_10_fd_mbps, (bool, type(None))) is True:
            self.advertise_10_fd_mbps = advertise_10_fd_mbps
        else:
            raise TypeError('advertise_10_fd_mbps must be an instance of (bool, type(None))')
        if isinstance(advertise_10_hd_mbps, (bool, type(None))) is True:
            self.advertise_10_hd_mbps = advertise_10_hd_mbps
        else:
            raise TypeError('advertise_10_hd_mbps must be an instance of (bool, type(None))')
        if isinstance(link_training, (bool, type(None))) is True:
            self.link_training = link_training
        else:
            raise TypeError('link_training must be an instance of (bool, type(None))')
        if isinstance(rs_fec, (bool, type(None))) is True:
            self.rs_fec = rs_fec
        else:
            raise TypeError('rs_fec must be an instance of (bool, type(None))')


class FlowControl(object):
    """Generated from OpenAPI schema object #/components/schemas/Layer1.FlowControl

    A container for layer1 receive flow control settings  
    To enable flow control settings on ports this object must be a valid object not a null value  

    Args
    ----
    - directed_address (str): The 48bit mac address that the layer1 port names will listen on for a directed pause
    - choice (Union[Ieee8021qbb, Ieee8023x]): The type of priority flow control
    """
    _CHOICE_MAP = {
        'Ieee8021qbb': 'ieee_802_1qbb',
        'Ieee8023x': 'ieee_802_3x',
    }
    def __init__(self, directed_address='0180C2000001', choice=None):
        from abstract_open_traffic_generator.layer1 import Ieee8021qbb
        from abstract_open_traffic_generator.layer1 import Ieee8023x
        if isinstance(choice, (Ieee8021qbb, Ieee8023x)) is False:
            raise TypeError('choice must be of type: Ieee8021qbb, Ieee8023x')
        self.__setattr__('choice', FlowControl._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(FlowControl._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(directed_address, (str, type(None))) is True:
            self.directed_address = directed_address
        else:
            raise TypeError('directed_address must be an instance of (str, type(None))')


class Ieee8023x(object):
    """Generated from OpenAPI schema object #/components/schemas/Layer1.Ieee8023x

    A container for ieee 802.3x rx pause settings  
    """
    def __init__(self):
        pass


class Ieee8021qbb(object):
    """Generated from OpenAPI schema object #/components/schemas/Layer1.Ieee8021qbb

    These settings enhance the existing 802.3x pause priority capabilities to enable flow control based on 802.1p priorities (classes of service)  

    Args
    ----
    - pfc_delay (int): The upper limit on the transmit time of a queue after receiving a message to pause a specified priority
     A value of 0 or null indicates that pfc delay will not be enabled
    - pfc_class_0 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_1 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_2 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_3 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_4 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_5 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_6 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    - pfc_class_7 (int): The valid values are null, 0 - 7
     A null value indicates there is no setting for this pfc class
    """
    def __init__(self, pfc_delay=None, pfc_class_0=None, pfc_class_1=None, pfc_class_2=None, pfc_class_3=None, pfc_class_4=None, pfc_class_5=None, pfc_class_6=None, pfc_class_7=None):
        if isinstance(pfc_delay, (float, int, type(None))) is True:
            self.pfc_delay = pfc_delay
        else:
            raise TypeError('pfc_delay must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_0, (float, int, type(None))) is True:
            self.pfc_class_0 = pfc_class_0
        else:
            raise TypeError('pfc_class_0 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_1, (float, int, type(None))) is True:
            self.pfc_class_1 = pfc_class_1
        else:
            raise TypeError('pfc_class_1 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_2, (float, int, type(None))) is True:
            self.pfc_class_2 = pfc_class_2
        else:
            raise TypeError('pfc_class_2 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_3, (float, int, type(None))) is True:
            self.pfc_class_3 = pfc_class_3
        else:
            raise TypeError('pfc_class_3 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_4, (float, int, type(None))) is True:
            self.pfc_class_4 = pfc_class_4
        else:
            raise TypeError('pfc_class_4 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_5, (float, int, type(None))) is True:
            self.pfc_class_5 = pfc_class_5
        else:
            raise TypeError('pfc_class_5 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_6, (float, int, type(None))) is True:
            self.pfc_class_6 = pfc_class_6
        else:
            raise TypeError('pfc_class_6 must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_7, (float, int, type(None))) is True:
            self.pfc_class_7 = pfc_class_7
        else:
            raise TypeError('pfc_class_7 must be an instance of (float, int, type(None))')





class Api(object):
    """TBD
    """

    def set_state(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_state_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_capability_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_config(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_port_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_capture_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_flow_results(self, content):
        """TBD
        """
        raise NotImplementedError

    def get_bgpv4_results(self, content):
        """TBD
        """
        raise NotImplementedError





class Config(object):
    """Generated from OpenAPI schema object #/components/schemas/Config

    A container for all models that are part of the configuration  

    Args
    ----
    - ports (list[Port]): The ports that will be configured on the traffic generator
    - lags (list[Lag]): The lags that will be configured on the traffic generator
    - layer1 (list[Layer1]): The layer1 settings that will be configured on the traffic generator
    - captures (list[Capture]): The capture settings that will be configured on the traffic generator
    - devices (list[Device]): The emulated device settings that will be configured on the traffic generator
    - flows (list[Flow]): The flows that will be configured on the traffic generator
    - options (Options): Global configuration options
    """
    def __init__(self, ports=[], lags=[], layer1=[], captures=[], devices=[], flows=[], options=None):
        from abstract_open_traffic_generator.config import Options
        if isinstance(ports, (list, type(None))) is True:
            self.ports = [] if ports is None else list(ports)
        else:
            raise TypeError('ports must be an instance of (list, type(None))')
        if isinstance(lags, (list, type(None))) is True:
            self.lags = [] if lags is None else list(lags)
        else:
            raise TypeError('lags must be an instance of (list, type(None))')
        if isinstance(layer1, (list, type(None))) is True:
            self.layer1 = [] if layer1 is None else list(layer1)
        else:
            raise TypeError('layer1 must be an instance of (list, type(None))')
        if isinstance(captures, (list, type(None))) is True:
            self.captures = [] if captures is None else list(captures)
        else:
            raise TypeError('captures must be an instance of (list, type(None))')
        if isinstance(devices, (list, type(None))) is True:
            self.devices = [] if devices is None else list(devices)
        else:
            raise TypeError('devices must be an instance of (list, type(None))')
        if isinstance(flows, (list, type(None))) is True:
            self.flows = [] if flows is None else list(flows)
        else:
            raise TypeError('flows must be an instance of (list, type(None))')
        if isinstance(options, (Options, type(None))) is True:
            self.options = options
        else:
            raise TypeError('options must be an instance of (Options, type(None))')


class Options(object):
    """Generated from OpenAPI schema object #/components/schemas/Config.Options

    Global configuration options  

    Args
    ----
    - port_options (Options): Common port options that apply to all configured Port
     Port objects
    """
    def __init__(self, port_options=None):
        from abstract_open_traffic_generator.port import Options
        if isinstance(port_options, (Options, type(None))) is True:
            self.port_options = port_options
        else:
            raise TypeError('port_options must be an instance of (Options, type(None))')





class Capture(object):
    """Generated from OpenAPI schema object #/components/schemas/Capture

    Container for capture settings  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - port_names (list[str]): The unique names of ports that the capture settings will apply to
    - choice (Union[list, str]): The type of filter
    - enable (Union[True, False]): Enable capture on the port
    - overwrite (Union[True, False]): Overwrite the capture buffer
    - format (Union[pcap, pcapng]): The format of the capture file
    """
    _CHOICE_MAP = {
        'list': 'basic',
        'str': 'pcap',
    }
    def __init__(self, name=None, port_names=[], choice=None, enable=True, overwrite=False, format='pcap'):
        if isinstance(choice, (list, str)) is False:
            raise TypeError('choice must be of type: list, str')
        self.__setattr__('choice', Capture._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Capture._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(port_names, (list, type(None))) is True:
            self.port_names = [] if port_names is None else list(port_names)
        else:
            raise TypeError('port_names must be an instance of (list, type(None))')
        if isinstance(enable, (bool, type(None))) is True:
            self.enable = enable
        else:
            raise TypeError('enable must be an instance of (bool, type(None))')
        if isinstance(overwrite, (bool, type(None))) is True:
            self.overwrite = overwrite
        else:
            raise TypeError('overwrite must be an instance of (bool, type(None))')
        if isinstance(format, (str, type(None))) is True:
            self.format = format
        else:
            raise TypeError('format must be an instance of (str, type(None))')


class BasicFilter(object):
    """Generated from OpenAPI schema object #/components/schemas/Capture.BasicFilter

    A container for different types of basic capture filters  

    Args
    ----
    - choice (Union[MacAddressFilter, CustomFilter]): TBD
    - and_operator (Union[True, False]): TBD
    - not_operator (Union[True, False]): TBD
    """
    _CHOICE_MAP = {
        'MacAddressFilter': 'mac_address',
        'CustomFilter': 'custom',
    }
    def __init__(self, choice=None, and_operator=True, not_operator=False):
        from abstract_open_traffic_generator.capture import MacAddressFilter
        from abstract_open_traffic_generator.capture import CustomFilter
        if isinstance(choice, (MacAddressFilter, CustomFilter)) is False:
            raise TypeError('choice must be of type: MacAddressFilter, CustomFilter')
        self.__setattr__('choice', BasicFilter._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(BasicFilter._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(and_operator, (bool, type(None))) is True:
            self.and_operator = and_operator
        else:
            raise TypeError('and_operator must be an instance of (bool, type(None))')
        if isinstance(not_operator, (bool, type(None))) is True:
            self.not_operator = not_operator
        else:
            raise TypeError('not_operator must be an instance of (bool, type(None))')


class MacAddressFilter(object):
    """Generated from OpenAPI schema object #/components/schemas/Capture.MacAddressFilter

    A container for a mac address capture filter  

    Args
    ----
    - mac (Union[source, destination]): The type of mac address filters
     This can be either source or destination
    - filter (str): The value of the mac address
    - mask (str): The value of the mask to be applied to the mac address
    """
    def __init__(self, mac=None, filter=None, mask=None):
        if isinstance(mac, (str)) is True:
            self.mac = mac
        else:
            raise TypeError('mac must be an instance of (str)')
        if isinstance(filter, (str)) is True:
            self.filter = filter
        else:
            raise TypeError('filter must be an instance of (str)')
        if isinstance(mask, (str, type(None))) is True:
            self.mask = mask
        else:
            raise TypeError('mask must be an instance of (str, type(None))')


class CustomFilter(object):
    """Generated from OpenAPI schema object #/components/schemas/Capture.CustomFilter

    A container for a custom capture filter  

    Args
    ----
    - filter (str): The value to filter on
    - mask (str): The mask to be applied to the filter
    - offset (int): The offset in the packet to filter at
    """
    def __init__(self, filter=None, mask=None, offset=None):
        if isinstance(filter, (str)) is True:
            self.filter = filter
        else:
            raise TypeError('filter must be an instance of (str)')
        if isinstance(mask, (str, type(None))) is True:
            self.mask = mask
        else:
            raise TypeError('mask must be an instance of (str, type(None))')
        if isinstance(offset, (float, int)) is True:
            self.offset = offset
        else:
            raise TypeError('offset must be an instance of (float, int)')





class State(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.State

    A container for the different types of states  

    Args
    ----
    - choice (Union[ConfigState, PortLinkState, PortCaptureState, FlowTransmitState, Bgpv4RouteAction, Bgpv6RouteAction]): TBD
    """
    _CHOICE_MAP = {
        'ConfigState': 'config_state',
        'PortLinkState': 'port_link_state',
        'PortCaptureState': 'port_capture_state',
        'FlowTransmitState': 'flow_transmit_state',
        'Bgpv4RouteAction': 'bgpv4_route_action',
        'Bgpv6RouteAction': 'bgpv6_route_action',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.control import ConfigState
        from abstract_open_traffic_generator.control import PortLinkState
        from abstract_open_traffic_generator.control import PortCaptureState
        from abstract_open_traffic_generator.control import FlowTransmitState
        from abstract_open_traffic_generator.control import Bgpv4RouteAction
        from abstract_open_traffic_generator.control import Bgpv6RouteAction
        if isinstance(choice, (ConfigState, PortLinkState, PortCaptureState, FlowTransmitState, Bgpv4RouteAction, Bgpv6RouteAction)) is False:
            raise TypeError('choice must be of type: ConfigState, PortLinkState, PortCaptureState, FlowTransmitState, Bgpv4RouteAction, Bgpv6RouteAction')
        self.__setattr__('choice', State._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(State._CHOICE_MAP[type(choice).__name__], choice)


class ConfigState(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.ConfigState

    Control the configuration state on the traffic generator  

    Args
    ----
    - config (Config): A container for all models that are part of the configuration
    - state (Union[set, update]): Set the configuration state on the traffic generator
     - set is used to submit a complete running configuration on the traffic generator
     - update is used to submit a partial configuration which will be merged with the current running configuration on the traffic generator
    """
    def __init__(self, config=None, state=None):
        from abstract_open_traffic_generator.config import Config
        if isinstance(config, (Config)) is True:
            self.config = config
        else:
            raise TypeError('config must be an instance of (Config)')
        if isinstance(state, (str)) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (str)')


class PortLinkState(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.PortLinkState

    Control port link state  

    Args
    ----
    - port_names (list[str]): The names of port objects to
     An empty or null list will control all port objects
    - state (Union[up, down]): The link state
    """
    def __init__(self, port_names=[], state=None):
        if isinstance(port_names, (list, type(None))) is True:
            self.port_names = [] if port_names is None else list(port_names)
        else:
            raise TypeError('port_names must be an instance of (list, type(None))')
        if isinstance(state, (str)) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (str)')


class FlowTransmitState(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.FlowTransmitState

    Control flow transmit state  

    Args
    ----
    - flow_names (list[str]): The names of flow objects to control
     An empty or null list will control all flow objects
    - state (Union[start, stop, pause]): The transmit state
    """
    def __init__(self, flow_names=[], state=None):
        if isinstance(flow_names, (list, type(None))) is True:
            self.flow_names = [] if flow_names is None else list(flow_names)
        else:
            raise TypeError('flow_names must be an instance of (list, type(None))')
        if isinstance(state, (str)) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (str)')


class PortCaptureState(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.PortCaptureState

    Control port capture state  

    Args
    ----
    - port_names (list[str]): The name of ports to start capturing packets on
     An empty or null list will control all port objects
    - state (Union[start, stop]): The capture state
    """
    def __init__(self, port_names=[], state=None):
        if isinstance(port_names, (list, type(None))) is True:
            self.port_names = [] if port_names is None else list(port_names)
        else:
            raise TypeError('port_names must be an instance of (list, type(None))')
        if isinstance(state, (str)) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (str)')


class Bgpv4RouteAction(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.Bgpv4RouteAction

    BGPv4 route specific action  

    Args
    ----
    - names (list[str]): The names of Bgpv4RouteRange object to control
    - action (Union[withdraw_routes, advertise_routes]): BGPv4 route specific action
    """
    def __init__(self, names=[], action=None):
        if isinstance(names, (list, type(None))) is True:
            self.names = [] if names is None else list(names)
        else:
            raise TypeError('names must be an instance of (list, type(None))')
        if isinstance(action, (str)) is True:
            self.action = action
        else:
            raise TypeError('action must be an instance of (str)')


class Bgpv6RouteAction(object):
    """Generated from OpenAPI schema object #/components/schemas/Control.Bgpv6RouteAction

    BGPv6 route specific action  

    Args
    ----
    - names (list[str]): The names of Bgpv6RouteRange object to control
    - action (Union[withdraw_routes, advertise_routes]): BGPv6 route specific action
    """
    def __init__(self, names=[], action=None):
        if isinstance(names, (list, type(None))) is True:
            self.names = [] if names is None else list(names)
        else:
            raise TypeError('names must be an instance of (list, type(None))')
        if isinstance(action, (str)) is True:
            self.action = action
        else:
            raise TypeError('action must be an instance of (str)')



import pytest


def test_choice(serializer):
    from abstract_open_traffic_generator.flow import Flow, TxRx, PortTxRx
    try:
        flow = Flow(name='test', tx_rx=TxRx())
        assert('Expected a TypeError when assigning physical')
    except TypeError as e:
        print(e)
        pass

def test_string(serializer):
    from abstract_open_traffic_generator.port import Port
    try:
        port = Port(name=1)
        assert('Expected a TypeError when assigning name')
    except TypeError as e:
        print(e)
        pass

if __name__ == '__main__':
    pytest.main(['-s', __file__])





class Lag(object):
    """Generated from OpenAPI schema object #/components/schemas/Lag

    A container for LAG settings  

    Args
    ----
    - name (str): Unique system wide name of an object that is also the primary key for objects found in arrays
    - port_names (list[str]): A list of unique names of port objects that will be part of the same lag
     The value of the port_names property is the count for any child property in this hierarchy that is a container for a device pattern
    - protocol (Protocol): Static lag or LACP protocol settings
    - ethernet (Ethernet): Emulated ethernet protocol
     A top level in the emulated device stack
     Per port ethernet and vlan settings
    """
    def __init__(self, name=None, port_names=[], protocol=None, ethernet=None):
        from abstract_open_traffic_generator.lag import Protocol
        from abstract_open_traffic_generator.device import Ethernet
        if isinstance(name, (str)) is True:
            import re
            assert(bool(re.match(r'^[\sa-zA-Z0-9-_()><\[\]]+$', name)) is True)
            self.name = name
        else:
            raise TypeError('name must be an instance of (str)')
        if isinstance(port_names, (list, type(None))) is True:
            self.port_names = [] if port_names is None else list(port_names)
        else:
            raise TypeError('port_names must be an instance of (list, type(None))')
        if isinstance(protocol, (Protocol)) is True:
            self.protocol = protocol
        else:
            raise TypeError('protocol must be an instance of (Protocol)')
        if isinstance(ethernet, (Ethernet, type(None))) is True:
            self.ethernet = ethernet
        else:
            raise TypeError('ethernet must be an instance of (Ethernet, type(None))')


class Protocol(object):
    """Generated from OpenAPI schema object #/components/schemas/Lag.Protocol

    TBD  

    Args
    ----
    - choice (Union[Lacp, Static]): The type of lag protocol
    """
    _CHOICE_MAP = {
        'Lacp': 'lacp',
        'Static': 'static',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.lag import Lacp
        from abstract_open_traffic_generator.lag import Static
        if isinstance(choice, (Lacp, Static)) is False:
            raise TypeError('choice must be of type: Lacp, Static')
        self.__setattr__('choice', Protocol._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Protocol._CHOICE_MAP[type(choice).__name__], choice)


class Static(object):
    """Generated from OpenAPI schema object #/components/schemas/Lag.Static

    TBD  

    Args
    ----
    - lag_id (Pattern): A container for emulated device property patterns
     The static lag id
    """
    def __init__(self, lag_id=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(lag_id, (Pattern, type(None))) is True:
            self.lag_id = lag_id
        else:
            raise TypeError('lag_id must be an instance of (Pattern, type(None))')


class Lacp(object):
    """Generated from OpenAPI schema object #/components/schemas/Lag.Lacp

    TBD  

    Args
    ----
    - actor_key (Pattern): A container for emulated device property patterns
     The actor key
    - actor_port_number (Pattern): A container for emulated device property patterns
     The actor port number
    - actor_port_priority (Pattern): A container for emulated device property patterns
     The actor port priority
    - actor_system_id (Pattern): A container for emulated device property patterns
     The actor system id
    - actor_system_priority (Pattern): A container for emulated device property patterns
     The actor system priority
    """
    def __init__(self, actor_key=None, actor_port_number=None, actor_port_priority=None, actor_system_id=None, actor_system_priority=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(actor_key, (Pattern, type(None))) is True:
            self.actor_key = actor_key
        else:
            raise TypeError('actor_key must be an instance of (Pattern, type(None))')
        if isinstance(actor_port_number, (Pattern, type(None))) is True:
            self.actor_port_number = actor_port_number
        else:
            raise TypeError('actor_port_number must be an instance of (Pattern, type(None))')
        if isinstance(actor_port_priority, (Pattern, type(None))) is True:
            self.actor_port_priority = actor_port_priority
        else:
            raise TypeError('actor_port_priority must be an instance of (Pattern, type(None))')
        if isinstance(actor_system_id, (Pattern, type(None))) is True:
            self.actor_system_id = actor_system_id
        else:
            raise TypeError('actor_system_id must be an instance of (Pattern, type(None))')
        if isinstance(actor_system_priority, (Pattern, type(None))) is True:
            self.actor_system_priority = actor_system_priority
        else:
            raise TypeError('actor_system_priority must be an instance of (Pattern, type(None))')





class RequestConflict(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.RequestConflict

    Container for a request conflict  

    Args
    ----
    - current (str): Informational message describing the currently executing request
    """
    def __init__(self, current=None):
        if isinstance(current, (str, type(None))) is True:
            self.current = current
        else:
            raise TypeError('current must be an instance of (str, type(None))')


class RequestPending(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.RequestPending

    The standard response to any request  
    This allows an implementation to be either async or sync  

    Args
    ----
    - state (Union[pending, success]): TBD
    - url (str): The url to poll while the state is pending
    """
    def __init__(self, state=None, url=None):
        if isinstance(state, (str, type(None))) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (str, type(None))')
        if isinstance(url, (str, type(None))) is True:
            self.url = url
        else:
            raise TypeError('url must be an instance of (str, type(None))')


class RequestDetail(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.RequestDetail

    TBD  

    Args
    ----
    - errors (list[str]): A list of any details that may have occurred while executing the request
    """
    def __init__(self, errors=[]):
        if isinstance(errors, (list, type(None))) is True:
            self.errors = [] if errors is None else list(errors)
        else:
            raise TypeError('errors must be an instance of (list, type(None))')


class State(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.State

    A container for the different types of states  

    Args
    ----
    - port_state (list[PortState]): TBD
    - flow_state (list[FlowState]): TBD
    """
    def __init__(self, port_state=[], flow_state=[]):
        if isinstance(port_state, (list, type(None))) is True:
            self.port_state = [] if port_state is None else list(port_state)
        else:
            raise TypeError('port_state must be an instance of (list, type(None))')
        if isinstance(flow_state, (list, type(None))) is True:
            self.flow_state = [] if flow_state is None else list(flow_state)
        else:
            raise TypeError('flow_state must be an instance of (list, type(None))')


class PortState(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.PortState

    TBD  

    Args
    ----
    - name (str): TBD
    - link (Union[up, down]): TBD
    - capture (Union[started, stopped]): TBD
    """
    def __init__(self, name=None, link=None, capture=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(link, (str, type(None))) is True:
            self.link = link
        else:
            raise TypeError('link must be an instance of (str, type(None))')
        if isinstance(capture, (str, type(None))) is True:
            self.capture = capture
        else:
            raise TypeError('capture must be an instance of (str, type(None))')


class FlowState(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.FlowState

    TBD  

    Args
    ----
    - name (str): TBD
    - transmit (Union[started, stopped, paused]): TBD
    """
    def __init__(self, name=None, transmit=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(transmit, (str, type(None))) is True:
            self.transmit = transmit
        else:
            raise TypeError('transmit must be an instance of (str, type(None))')


class Table(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Table

    A table of result values  
    Each row in the table is an object  
    """
    def __init__(self):
        pass


class Capability(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Capability

    A list of capabilities of the implementation  

    Args
    ----
    - unsupported (list[str]): A list of /components/schemas/
     paths that are not supported
    - formats (list[str]): A /components/schemas/
     path and specific format details regarding the path
     Specific model format details can be additional objects and properties represented as a hashmap
     For example layer1 models are defined as a hashmap key to object with each object consisting of a specific name/value property pairs
     This list of items will detail any specific formats, properties, enums
    """
    def __init__(self, unsupported=[], formats=[]):
        if isinstance(unsupported, (list, type(None))) is True:
            self.unsupported = [] if unsupported is None else list(unsupported)
        else:
            raise TypeError('unsupported must be an instance of (list, type(None))')
        if isinstance(formats, (list, type(None))) is True:
            self.formats = [] if formats is None else list(formats)
        else:
            raise TypeError('formats must be an instance of (list, type(None))')


class PortRequest(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.PortRequest

    The port result request to the traffic generator  

    Args
    ----
    - port_names (list[str]): The names of objects to return results for
     An empty list will return all port row results
    - column_names (list[str]): The names of Result
     Port properties to return
     If the list is empty then all properties will be returned
    """
    def __init__(self, port_names=[], column_names=[]):
        if isinstance(port_names, (list, type(None))) is True:
            self.port_names = [] if port_names is None else list(port_names)
        else:
            raise TypeError('port_names must be an instance of (list, type(None))')
        if isinstance(column_names, (list, type(None))) is True:
            self.column_names = [] if column_names is None else list(column_names)
        else:
            raise TypeError('column_names must be an instance of (list, type(None))')


class Port(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Port

    TBD  

    Args
    ----
    - name (str): The name of a configured port
    - location (str): The state of the connection to the test port location
     The format should be the configured port location along with any custom connection state message
    - link (Union[up, down]): The state of the test port link The string can be up, down or a custom error message
    - capture (Union[started, stopped]): The state of the test port capture infrastructure
     The string can be started, stopped or a custom error message
    - frames_tx (int): The current total number of frames transmitted
    - frames_rx (int): The current total number of valid frames received
    - bytes_tx (int): The current total number of bytes transmitted
    - bytes_rx (int): The current total number of valid bytes received
    - frames_tx_rate (Union[float, int]): The current rate of frames transmitted
    - frames_rx_rate (Union[float, int]): The current rate of valid frames received
    - bytes_tx_rate (Union[float, int]): The current rate of bytes transmitted
    - bytes_rx_rate (Union[float, int]): The current rate of bytes received
    - pfc_class_0_frames_rx (int): The current total number of pfc class 0 frames received
    - pfc_class_1_frames_rx (int): The current total number of pfc class 1 frames received
    - pfc_class_2_frames_rx (int): The current total number of pfc class 2 frames received
    - pfc_class_3_frames_rx (int): The current total number of pfc class 3 frames received
    - pfc_class_4_frames_rx (int): The current total number of pfc class 4 frames received
    - pfc_class_5_frames_rx (Union[float, int]): The current total number of pfc class 5 frames received
    - pfc_class_6_frames_rx (int): The current total number of pfc class 6 frames received
    - pfc_class_7_frames_rx (int): The current total number of pfc class 7 frames received
    """
    def __init__(self, name=None, location=None, link=None, capture=None, frames_tx=None, frames_rx=None, bytes_tx=None, bytes_rx=None, frames_tx_rate=None, frames_rx_rate=None, bytes_tx_rate=None, bytes_rx_rate=None, pfc_class_0_frames_rx=None, pfc_class_1_frames_rx=None, pfc_class_2_frames_rx=None, pfc_class_3_frames_rx=None, pfc_class_4_frames_rx=None, pfc_class_5_frames_rx=None, pfc_class_6_frames_rx=None, pfc_class_7_frames_rx=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(location, (str, type(None))) is True:
            self.location = location
        else:
            raise TypeError('location must be an instance of (str, type(None))')
        if isinstance(link, (str, type(None))) is True:
            self.link = link
        else:
            raise TypeError('link must be an instance of (str, type(None))')
        if isinstance(capture, (str, type(None))) is True:
            self.capture = capture
        else:
            raise TypeError('capture must be an instance of (str, type(None))')
        if isinstance(frames_tx, (float, int, type(None))) is True:
            self.frames_tx = frames_tx
        else:
            raise TypeError('frames_tx must be an instance of (float, int, type(None))')
        if isinstance(frames_rx, (float, int, type(None))) is True:
            self.frames_rx = frames_rx
        else:
            raise TypeError('frames_rx must be an instance of (float, int, type(None))')
        if isinstance(bytes_tx, (float, int, type(None))) is True:
            self.bytes_tx = bytes_tx
        else:
            raise TypeError('bytes_tx must be an instance of (float, int, type(None))')
        if isinstance(bytes_rx, (float, int, type(None))) is True:
            self.bytes_rx = bytes_rx
        else:
            raise TypeError('bytes_rx must be an instance of (float, int, type(None))')
        if isinstance(frames_tx_rate, (float, int, type(None))) is True:
            self.frames_tx_rate = frames_tx_rate
        else:
            raise TypeError('frames_tx_rate must be an instance of (float, int, type(None))')
        if isinstance(frames_rx_rate, (float, int, type(None))) is True:
            self.frames_rx_rate = frames_rx_rate
        else:
            raise TypeError('frames_rx_rate must be an instance of (float, int, type(None))')
        if isinstance(bytes_tx_rate, (float, int, type(None))) is True:
            self.bytes_tx_rate = bytes_tx_rate
        else:
            raise TypeError('bytes_tx_rate must be an instance of (float, int, type(None))')
        if isinstance(bytes_rx_rate, (float, int, type(None))) is True:
            self.bytes_rx_rate = bytes_rx_rate
        else:
            raise TypeError('bytes_rx_rate must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_0_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_0_frames_rx = pfc_class_0_frames_rx
        else:
            raise TypeError('pfc_class_0_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_1_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_1_frames_rx = pfc_class_1_frames_rx
        else:
            raise TypeError('pfc_class_1_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_2_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_2_frames_rx = pfc_class_2_frames_rx
        else:
            raise TypeError('pfc_class_2_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_3_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_3_frames_rx = pfc_class_3_frames_rx
        else:
            raise TypeError('pfc_class_3_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_4_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_4_frames_rx = pfc_class_4_frames_rx
        else:
            raise TypeError('pfc_class_4_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_5_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_5_frames_rx = pfc_class_5_frames_rx
        else:
            raise TypeError('pfc_class_5_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_6_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_6_frames_rx = pfc_class_6_frames_rx
        else:
            raise TypeError('pfc_class_6_frames_rx must be an instance of (float, int, type(None))')
        if isinstance(pfc_class_7_frames_rx, (float, int, type(None))) is True:
            self.pfc_class_7_frames_rx = pfc_class_7_frames_rx
        else:
            raise TypeError('pfc_class_7_frames_rx must be an instance of (float, int, type(None))')


class CaptureRequest(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.CaptureRequest

    The capture result request to the traffic generator  
    Stops the port capture on the port_name and returns the capture  

    Args
    ----
    - port_name (str): The name of a port a capture is started on
    """
    def __init__(self, port_name=None):
        if isinstance(port_name, (str)) is True:
            self.port_name = port_name
        else:
            raise TypeError('port_name must be an instance of (str)')


class FlowRequest(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.FlowRequest

    The request to the traffic generator for flow results  

    Args
    ----
    - flow_names (list[str]): The names of flow objects to return results for
     An empty list will return results for all flows
    - column_names (list[str]): The names of Result
     Flow properties to return
     If the list is empty then all properties will be returned
    - ingress_result_names (list[str]): Add any configured Flow
     Pattern
     ingress_result_name values that are to be included in the results
     If the name is not configured then it will be excluded from the Result
     Flow
     columns and Result
     Flow
     rows
     The name in the Result
     Flow
     columns will be a combination of the ingress_result_name and any system assigned name
    """
    def __init__(self, flow_names=[], column_names=[], ingress_result_names=[]):
        if isinstance(flow_names, (list, type(None))) is True:
            self.flow_names = [] if flow_names is None else list(flow_names)
        else:
            raise TypeError('flow_names must be an instance of (list, type(None))')
        if isinstance(column_names, (list, type(None))) is True:
            self.column_names = [] if column_names is None else list(column_names)
        else:
            raise TypeError('column_names must be an instance of (list, type(None))')
        if isinstance(ingress_result_names, (list, type(None))) is True:
            self.ingress_result_names = [] if ingress_result_names is None else list(ingress_result_names)
        else:
            raise TypeError('ingress_result_names must be an instance of (list, type(None))')


class Flow(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Flow

    TBD  

    Args
    ----
    - name (str): The name of a configured flow
    - transmit (Union[started, stopped, paused]): The transmit state of the flow
    - port_tx (str): The name of a configured port
    - port_rx (str): The name of a configured port
    - frames_tx (int): The current total number of frames transmitted
    - frames_rx (int): The current total number of valid frames received
    - bytes_tx (int): The current total number of bytes transmitted
    - bytes_rx (int): The current total number of bytes received
    - frames_tx_rate (Union[float, int]): The current rate of frames transmitted
    - frames_rx_rate (Union[float, int]): The current rate of valid frames received
    - loss (Union[float, int]): The percentage of lost frames
    - additional_properties (**additional_properties): Any requested ingress result names will appear as additional name/value pairs
     Ingress result names will be the keys in string format
     Ingress result values will be in number format
    """
    def __init__(self, name=None, transmit=None, port_tx=None, port_rx=None, frames_tx=None, frames_rx=None, bytes_tx=None, bytes_rx=None, frames_tx_rate=None, frames_rx_rate=None, loss=None, additionalProperties=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(transmit, (str, type(None))) is True:
            self.transmit = transmit
        else:
            raise TypeError('transmit must be an instance of (str, type(None))')
        if isinstance(port_tx, (str, type(None))) is True:
            self.port_tx = port_tx
        else:
            raise TypeError('port_tx must be an instance of (str, type(None))')
        if isinstance(port_rx, (str, type(None))) is True:
            self.port_rx = port_rx
        else:
            raise TypeError('port_rx must be an instance of (str, type(None))')
        if isinstance(frames_tx, (float, int, type(None))) is True:
            self.frames_tx = frames_tx
        else:
            raise TypeError('frames_tx must be an instance of (float, int, type(None))')
        if isinstance(frames_rx, (float, int, type(None))) is True:
            self.frames_rx = frames_rx
        else:
            raise TypeError('frames_rx must be an instance of (float, int, type(None))')
        if isinstance(bytes_tx, (float, int, type(None))) is True:
            self.bytes_tx = bytes_tx
        else:
            raise TypeError('bytes_tx must be an instance of (float, int, type(None))')
        if isinstance(bytes_rx, (float, int, type(None))) is True:
            self.bytes_rx = bytes_rx
        else:
            raise TypeError('bytes_rx must be an instance of (float, int, type(None))')
        if isinstance(frames_tx_rate, (float, int, type(None))) is True:
            self.frames_tx_rate = frames_tx_rate
        else:
            raise TypeError('frames_tx_rate must be an instance of (float, int, type(None))')
        if isinstance(frames_rx_rate, (float, int, type(None))) is True:
            self.frames_rx_rate = frames_rx_rate
        else:
            raise TypeError('frames_rx_rate must be an instance of (float, int, type(None))')
        if isinstance(loss, (float, int, type(None))) is True:
            self.loss = loss
        else:
            raise TypeError('loss must be an instance of (float, int, type(None))')
        if isinstance(additionalProperties, **additional_properties) is True:
            self.additionalProperties = additionalProperties
        else:
            raise TypeError('additionalProperties must be an instance of **additional_properties')


class Bgpv4Request(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Bgpv4Request

    The request to retrieve BGP Router statistics and learned routing information  

    Args
    ----
    - names (list[str]): The names of BGP objects to return results for
     An empty list will return results for all BGP
    """
    def __init__(self, names=[]):
        if isinstance(names, (list, type(None))) is True:
            self.names = [] if names is None else list(names)
        else:
            raise TypeError('names must be an instance of (list, type(None))')


class Bgpv4(object):
    """Generated from OpenAPI schema object #/components/schemas/Result.Bgpv4

    BGP Router statistics and learned routing information  

    Args
    ----
    - name (str): The name of a configured BGPv4 Object
    - sessions_total (int): Total number of session
    - sessions_up (int): Sessions are in active state
    - sessions_down (int): Sessions are not active state
    - sessions_not_started (int): Sessions not able to start due to some internal issue
    - routes_advertised (int): Number of advertised routes sent
    - routes_withdrawn (int): Number of routes withdrawn
    """
    def __init__(self, name=None, sessions_total=None, sessions_up=None, sessions_down=None, sessions_not_started=None, routes_advertised=None, routes_withdrawn=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(sessions_total, (float, int, type(None))) is True:
            self.sessions_total = sessions_total
        else:
            raise TypeError('sessions_total must be an instance of (float, int, type(None))')
        if isinstance(sessions_up, (float, int, type(None))) is True:
            self.sessions_up = sessions_up
        else:
            raise TypeError('sessions_up must be an instance of (float, int, type(None))')
        if isinstance(sessions_down, (float, int, type(None))) is True:
            self.sessions_down = sessions_down
        else:
            raise TypeError('sessions_down must be an instance of (float, int, type(None))')
        if isinstance(sessions_not_started, (float, int, type(None))) is True:
            self.sessions_not_started = sessions_not_started
        else:
            raise TypeError('sessions_not_started must be an instance of (float, int, type(None))')
        if isinstance(routes_advertised, (float, int, type(None))) is True:
            self.routes_advertised = routes_advertised
        else:
            raise TypeError('routes_advertised must be an instance of (float, int, type(None))')
        if isinstance(routes_withdrawn, (float, int, type(None))) is True:
            self.routes_withdrawn = routes_withdrawn
        else:
            raise TypeError('routes_withdrawn must be an instance of (float, int, type(None))')
